@@ -18,7 +18,7 @@
 
 using namespace Kleo;
 
-static constexpr QAccessible::Role ValueRole = static_cast<QAccessible::Role>(QAccessible::UserRole);
+static constexpr QAccessible::Role ValueRole = static_cast<QAccessible::Role>(QAccessible::UserRole + 1);
 
 AccessibleValueLabel::AccessibleValueLabel(QWidget *w)
     : QAccessibleWidget{w, ValueRole}
@@ -55,5 +55,5 @@ QString AccessibleValueLabel::text(QAccessible::Text t) const
 
 QLabel *AccessibleValueLabel::label() const
 {
-    return qobject_cast<QLabel*>(object());
+    return qobject_cast<QLabel *>(object());
 }
