@@ -20,22 +20,20 @@ using namespace Kleo::Commands;
 ClearCrlCacheCommand::ClearCrlCacheCommand(KeyListController *c)
     : GnuPGProcessCommand(c)
 {
-
 }
 
 ClearCrlCacheCommand::ClearCrlCacheCommand(QAbstractItemView *v, KeyListController *c)
     : GnuPGProcessCommand(v, c)
 {
-
 }
 
-ClearCrlCacheCommand::~ClearCrlCacheCommand() {}
+ClearCrlCacheCommand::~ClearCrlCacheCommand()
+{
+}
 
 QStringList ClearCrlCacheCommand::arguments() const
 {
-    return QStringList() << gpgSmPath()
-                         << QStringLiteral("--call-dirmngr")
-                         << QStringLiteral("flushcrls");
+    return {gpgSmPath(), QStringLiteral("--call-dirmngr"), QStringLiteral("flushcrls")};
 }
 
 QString ClearCrlCacheCommand::errorCaption() const
@@ -50,15 +48,20 @@ QString ClearCrlCacheCommand::successCaption() const
 
 QString ClearCrlCacheCommand::crashExitMessage(const QStringList &args) const
 {
-    return i18n("The DirMngr process that tried to clear the CRL cache "
-                "ended prematurely because of an unexpected error. "
-                "Please check the output of %1 for details.", args.join(QLatin1Char(' ')));
+    return i18n(
+        "The DirMngr process that tried to clear the CRL cache "
+        "ended prematurely because of an unexpected error. "
+        "Please check the output of %1 for details.",
+        args.join(QLatin1Char(' ')));
 }
 
 QString ClearCrlCacheCommand::errorExitMessage(const QStringList &args) const
 {
-    return i18n("An error occurred while trying to clear the CRL cache. "
-                "The output from %1 was:\n%2", args[0], errorString());
+    return i18n(
+        "An error occurred while trying to clear the CRL cache. "
+        "The output from %1 was:\n%2",
+        args[0],
+        errorString());
 }
 
 QString ClearCrlCacheCommand::successMessage(const QStringList &) const
@@ -66,3 +69,4 @@ QString ClearCrlCacheCommand::successMessage(const QStringList &) const
     return i18n("CRL cache cleared successfully.");
 }
 
+#include "moc_clearcrlcachecommand.cpp"
