@@ -10,12 +10,12 @@
 
 #include <config-kleopatra.h>
 
-#include "exportsecretkeycommand.h"
 #include "command_p.h"
+#include "exportsecretkeycommand.h"
 
 #include "fileoperationspreferences.h"
-#include <utils/applicationstate.h>
 #include "utils/filedialog.h"
+#include <utils/applicationstate.h>
 
 #include <Libkleo/Classify>
 #include <Libkleo/Formatting>
@@ -23,8 +23,8 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <QGpgME/Protocol>
 #include <QGpgME/ExportJob>
+#include <QGpgME/Protocol>
 
 #include <QFileInfo>
 #include <QStandardPaths>
@@ -46,14 +46,13 @@ namespace
 
 QString openPGPCertificateFileExtension()
 {
-    return QLatin1String{outputFileExtension(Class::OpenPGP | Class::Ascii | Class::Certificate,
-                                             FileOperationsPreferences().usePGPFileExt())};
+    return outputFileExtension(Class::OpenPGP | Class::Ascii | Class::Certificate, FileOperationsPreferences().usePGPFileExt());
 }
 
 QString cmsCertificateFileExtension()
 {
-    return QLatin1String{outputFileExtension(Class::CMS | Class::Binary | Class::ExportedPSM,
-                                             /*usePGPFileExt=*/false)};
+    return outputFileExtension(Class::CMS | Class::Binary | Class::ExportedPSM,
+                               /*usePGPFileExt=*/false);
 }
 
 QString certificateFileExtension(GpgME::Protocol protocol)
@@ -100,12 +99,11 @@ QString secretKeyFileFilters(GpgME::Protocol protocol)
 
 QString requestFilename(const Key &key, const QString &proposedFilename, QWidget *parent)
 {
-    auto filename = FileDialog::getSaveFileNameEx(
-        parent,
-        i18nc("@title:window", "Secret Key Backup"),
-        QStringLiteral("imp"),
-        proposedFilename,
-        secretKeyFileFilters(key.protocol()));
+    auto filename = FileDialog::getSaveFileNameEx(parent,
+                                                  i18nc("@title:window", "Secret Key Backup"),
+                                                  QStringLiteral("imp"),
+                                                  proposedFilename,
+                                                  secretKeyFileFilters(key.protocol()));
 
     if (!filename.isEmpty()) {
         const QFileInfo fi{filename};
@@ -132,6 +130,7 @@ class ExportSecretKeyCommand::Private : public Command::Private
     {
         return static_cast<ExportSecretKeyCommand *>(q);
     }
+
 public:
     explicit Private(ExportSecretKeyCommand *qq, KeyListController *c = nullptr);
     ~Private() override;
@@ -201,7 +200,6 @@ void ExportSecretKeyCommand::Private::cancel()
 
 std::unique_ptr<QGpgME::ExportJob> ExportSecretKeyCommand::Private::startExportJob(const Key &key)
 {
-#if QGPGME_SUPPORTS_SECRET_KEY_EXPORT
     const bool armor = key.protocol() == GpgME::OpenPGP && filename.endsWith(u".asc", Qt::CaseInsensitive);
     const QGpgME::Protocol *const backend = (key.protocol() == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
     Q_ASSERT(backend);
@@ -212,17 +210,10 @@ std::unique_ptr<QGpgME::ExportJob> ExportSecretKeyCommand::Private::startExportJ
         exportJob->setExportFlags(GpgME::Context::ExportPKCS12);
     }
 
-    connect(exportJob.get(), &QGpgME::ExportJob::result,
-            q, [this](const GpgME::Error &err, const QByteArray &keyData) {
-                onExportJobResult(err, keyData);
-            });
-#if QGPGME_JOB_HAS_NEW_PROGRESS_SIGNALS
-    connect(exportJob.get(), &QGpgME::Job::jobProgress,
-            q, &Command::progress);
-#else
-    connect(exportJob.get(), &QGpgME::Job::progress,
-            q, [this](const QString &, int current, int total) { Q_EMIT q->progress(current, total); });
-#endif
+    connect(exportJob.get(), &QGpgME::ExportJob::result, q, [this](const GpgME::Error &err, const QByteArray &keyData) {
+        onExportJobResult(err, keyData);
+    });
+    connect(exportJob.get(), &QGpgME::Job::jobProgress, q, &Command::progress);
 
     const GpgME::Error err = exportJob->start({QLatin1String{key.primaryFingerprint()}});
     if (err) {
@@ -232,10 +223,6 @@ std::unique_ptr<QGpgME::ExportJob> ExportSecretKeyCommand::Private::startExportJ
     Q_EMIT q->info(i18nc("@info:status", "Backing up secret key..."));
 
     return exportJob;
-#else
-    Q_UNUSED(key)
-    return {};
-#endif
 }
 
 void ExportSecretKeyCommand::Private::onExportJobResult(const Error &err, const QByteArray &keyData)
@@ -252,30 +239,26 @@ void ExportSecretKeyCommand::Private::onExportJobResult(const Error &err, const
     }
 
     if (keyData.isEmpty()) {
-        error(i18nc("@info", "The result of the backup is empty. Maybe you entered an empty or a wrong passphrase."),
-              errorCaption());
+        error(i18nc("@info", "The result of the backup is empty. Maybe you entered an empty or a wrong passphrase."), errorCaption());
         finished();
         return;
     }
 
     QFile f{filename};
     if (!f.open(QIODevice::WriteOnly)) {
-        error(xi18nc("@info", "Cannot open file <filename>%1</filename> for writing.", filename),
-              errorCaption());
+        error(xi18nc("@info", "Cannot open file <filename>%1</filename> for writing.", filename), errorCaption());
         finished();
         return;
     }
 
     const auto bytesWritten = f.write(keyData);
     if (bytesWritten != keyData.size()) {
-        error(xi18nc("@info", "Writing key to file <filename>%1</filename> failed.", filename),
-              errorCaption());
+        error(xi18nc("@info", "Writing key to file <filename>%1</filename> failed.", filename), errorCaption());
         finished();
         return;
     }
 
-    information(i18nc("@info", "The backup of the secret key was created successfully."),
-                i18nc("@title:window", "Secret Key Backup"));
+    information(i18nc("@info", "The backup of the secret key was created successfully."), i18nc("@title:window", "Secret Key Backup"));
     finished();
 }
 
