@@ -30,29 +30,27 @@
 #include <Libkleo/Stl_Util>
 
 #include <QGpgME/Debug>
-#include <QGpgME/Protocol>
-#include <QGpgME/KeyListJob>
 #include <QGpgME/ImportFromKeyserverJob>
-#if QGPGME_SUPPORTS_WKDLOOKUP
-# include <QGpgME/WKDLookupJob>
-# include <QGpgME/WKDLookupResult>
-#endif
+#include <QGpgME/KeyListJob>
+#include <QGpgME/Protocol>
+#include <QGpgME/WKDLookupJob>
+#include <QGpgME/WKDLookupResult>
 
 #include <gpgme++/data.h>
+#include <gpgme++/importresult.h>
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
-#include <gpgme++/importresult.h>
 
+#include "kleopatra_debug.h"
 #include <KLocalizedString>
 #include <KMessageBox>
-#include "kleopatra_debug.h"
 
 #include <QRegularExpression>
 
-#include <vector>
+#include <algorithm>
 #include <map>
 #include <set>
-#include <algorithm>
+#include <vector>
 
 using namespace Kleo;
 using namespace Kleo::Commands;
@@ -67,6 +65,7 @@ class LookupCertificatesCommand::Private : public ImportCertificatesCommand::Pri
     {
         return static_cast<LookupCertificatesCommand *>(q);
     }
+
 public:
     explicit Private(LookupCertificatesCommand *qq, KeyListController *c);
     ~Private() override;
@@ -77,9 +76,7 @@ private:
     void slotSearchTextChanged(const QString &str);
     void slotNextKey(const Key &key);
     void slotKeyListResult(const KeyListResult &result);
-#if QGPGME_SUPPORTS_WKDLOOKUP
     void slotWKDLookupResult(const WKDLookupResult &result);
-#endif
     void tryToFinishKeyLookup();
     void slotImportRequested(const std::vector<Key> &keys);
     void slotDetailsRequested(const Key &key);
@@ -99,22 +96,18 @@ private:
         const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
         return cbp ? cbp->keyListJob(true) : nullptr;
     }
-#if QGPGME_SUPPORTS_WKDLOOKUP
     WKDLookupJob *createWKDLookupJob() const
     {
         const auto cbp = QGpgME::openpgp();
         return cbp ? cbp->wkdLookupJob() : nullptr;
     }
-#endif
     ImportFromKeyserverJob *createImportJob(GpgME::Protocol proto) const
     {
         const auto cbp = (proto == GpgME::OpenPGP) ? QGpgME::openpgp() : QGpgME::smime();
         return cbp ? cbp->importFromKeyserverJob() : nullptr;
     }
     void startKeyListJob(GpgME::Protocol proto, const QString &str);
-#if QGPGME_SUPPORTS_WKDLOOKUP
     void startWKDLookupJob(const QString &str);
-#endif
     bool checkConfig() const;
 
     QWidget *dialogOrParentWidgetOrView() const
@@ -133,9 +126,7 @@ private:
     QPointer<LookupCertificatesDialog> dialog;
     struct KeyListingVariables {
         QPointer<KeyListJob> cms, openpgp;
-#if QGPGME_SUPPORTS_WKDLOOKUP
         QPointer<WKDLookupJob> wkdJob;
-#endif
         QString pattern;
         KeyListResult result;
         std::vector<Key> keys;
@@ -166,8 +157,8 @@ const LookupCertificatesCommand::Private *LookupCertificatesCommand::d_func() co
 #define q q_func()
 
 LookupCertificatesCommand::Private::Private(LookupCertificatesCommand *qq, KeyListController *c)
-    : ImportCertificatesCommand::Private(qq, c),
-      dialog()
+    : ImportCertificatesCommand::Private(qq, c)
+    , dialog()
 {
     if (!Settings{}.cmsEnabled()) {
         protocol = GpgME::OpenPGP;
@@ -207,7 +198,6 @@ LookupCertificatesCommand::LookupCertificatesCommand(QAbstractItemView *v, KeyLi
 
 void LookupCertificatesCommand::Private::init()
 {
-
 }
 
 LookupCertificatesCommand::~LookupCertificatesCommand()
@@ -227,7 +217,6 @@ GpgME::Protocol LookupCertificatesCommand::protocol() const
 
 void LookupCertificatesCommand::doStart()
 {
-
     if (!d->checkConfig()) {
         d->finished();
         return;
@@ -248,7 +237,6 @@ void LookupCertificatesCommand::doStart()
     }
 
     d->dialog->show();
-
 }
 
 void LookupCertificatesCommand::Private::createDialog()
@@ -259,12 +247,22 @@ void LookupCertificatesCommand::Private::createDialog()
     dialog = new LookupCertificatesDialog;
     applyWindowID(dialog);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
-    connect(dialog, &LookupCertificatesDialog::searchTextChanged, q, [this](const QString &text) { slotSearchTextChanged(text); });
+    connect(dialog, &LookupCertificatesDialog::searchTextChanged, q, [this](const QString &text) {
+        slotSearchTextChanged(text);
+    });
     using CertsVec = std::vector<GpgME::Key>;
-    connect(dialog, &LookupCertificatesDialog::saveAsRequested, q, [this](const CertsVec &certs) { slotSaveAsRequested(certs); });
-    connect(dialog, &LookupCertificatesDialog::importRequested, q, [this](const CertsVec &certs) { slotImportRequested(certs); });
-    connect(dialog, &LookupCertificatesDialog::detailsRequested, q, [this](const GpgME::Key &gpgKey) { slotDetailsRequested(gpgKey); });
-    connect(dialog, &QDialog::rejected, q, [this]() { slotDialogRejected(); });
+    connect(dialog, &LookupCertificatesDialog::saveAsRequested, q, [this](const CertsVec &certs) {
+        slotSaveAsRequested(certs);
+    });
+    connect(dialog, &LookupCertificatesDialog::importRequested, q, [this](const CertsVec &certs) {
+        slotImportRequested(certs);
+    });
+    connect(dialog, &LookupCertificatesDialog::detailsRequested, q, [this](const GpgME::Key &gpgKey) {
+        slotDetailsRequested(gpgKey);
+    });
+    connect(dialog, &QDialog::rejected, q, [this]() {
+        slotDialogRejected();
+    });
 }
 
 static auto searchTextToEmailAddress(const QString &s)
@@ -276,7 +274,7 @@ void LookupCertificatesCommand::Private::slotSearchTextChanged(const QString &st
 {
     // pressing return might trigger both search and dialog destruction (search focused and default key set)
     // On Windows, the dialog is then destroyed before this slot is called
-    if (dialog) {   //thus test
+    if (dialog) { // thus test
         dialog->setPassive(true);
         dialog->setCertificates(std::vector<Key>());
         dialog->showInformation({});
@@ -298,11 +296,9 @@ void LookupCertificatesCommand::Private::slotSearchTextChanged(const QString &st
             startKeyListJob(OpenPGP, QStringLiteral("0x") + str);
         } else {
             startKeyListJob(OpenPGP, str);
-#if QGPGME_SUPPORTS_WKDLOOKUP
             if (str.contains(QLatin1Char{'@'}) && !searchTextToEmailAddress(str).isEmpty()) {
                 startWKDLookupJob(str);
             }
-#endif
         }
     }
 }
@@ -313,18 +309,21 @@ void LookupCertificatesCommand::Private::startKeyListJob(GpgME::Protocol proto,
     if (!klj) {
         return;
     }
-    connect(klj, &QGpgME::KeyListJob::result, q, [this](const GpgME::KeyListResult &result) { slotKeyListResult(result); });
-    connect(klj, &QGpgME::KeyListJob::nextKey, q, [this](const GpgME::Key &key) { slotNextKey(key); });
+    connect(klj, &QGpgME::KeyListJob::result, q, [this](const GpgME::KeyListResult &result) {
+        slotKeyListResult(result);
+    });
+    connect(klj, &QGpgME::KeyListJob::nextKey, q, [this](const GpgME::Key &key) {
+        slotNextKey(key);
+    });
     if (const Error err = klj->start(QStringList(str))) {
         keyListing.result.mergeWith(KeyListResult(err));
     } else if (proto == CMS) {
-        keyListing.cms     = klj;
+        keyListing.cms = klj;
     } else {
         keyListing.openpgp = klj;
     }
 }
 
-#if QGPGME_SUPPORTS_WKDLOOKUP
 void LookupCertificatesCommand::Private::startWKDLookupJob(const QString &str)
 {
     const auto job = createWKDLookupJob();
@@ -332,15 +331,15 @@ void LookupCertificatesCommand::Private::startWKDLookupJob(const QString &str)
         qCDebug(KLEOPATRA_LOG) << "Failed to create WKDLookupJob";
         return;
     }
-    connect(job, &WKDLookupJob::result,
-            q, [this](const WKDLookupResult &result) { slotWKDLookupResult(result); });
+    connect(job, &WKDLookupJob::result, q, [this](const WKDLookupResult &result) {
+        slotWKDLookupResult(result);
+    });
     if (const Error err = job->start(str)) {
         keyListing.result.mergeWith(KeyListResult{err});
     } else {
         keyListing.wkdJob = job;
     }
 }
-#endif
 
 void LookupCertificatesCommand::Private::slotNextKey(const Key &key)
 {
@@ -375,21 +374,17 @@ void LookupCertificatesCommand::Private::slotKeyListResult(const KeyListResult &
     tryToFinishKeyLookup();
 }
 
-#if QGPGME_SUPPORTS_WKDLOOKUP
 static auto removeKeysNotMatchingEmail(const std::vector<Key> &keys, const std::string &email)
 {
     std::vector<Key> filteredKeys;
 
     const auto addrSpec = UserID::addrSpecFromString(email.c_str());
-    std::copy_if(std::begin(keys), std::end(keys),
-                 std::back_inserter(filteredKeys),
-                 [addrSpec](const auto &key) {
-                     const auto uids = key.userIDs();
-                     return std::any_of(std::begin(uids), std::end(uids),
-                                        [addrSpec](const auto &uid) {
-                                            return uid.addrSpec() == addrSpec;
-                                        });
-                 });
+    std::copy_if(std::begin(keys), std::end(keys), std::back_inserter(filteredKeys), [addrSpec](const auto &key) {
+        const auto uids = key.userIDs();
+        return std::any_of(std::begin(uids), std::end(uids), [addrSpec](const auto &uid) {
+            return uid.addrSpec() == addrSpec;
+        });
+    });
 
     return filteredKeys;
 }
@@ -410,17 +405,18 @@ void LookupCertificatesCommand::Private::slotWKDLookupResult(const WKDLookupResu
     if (!keys.empty()) {
         keyListing.wkdKeyData = QByteArray::fromStdString(result.keyData().toString());
         keyListing.wkdSource = QString::fromStdString(result.source());
-        std::copy(std::begin(keys), std::end(keys),
-                  std::back_inserter(keyListing.keys));
+        std::copy(std::begin(keys), std::end(keys), std::back_inserter(keyListing.keys));
         // remember the keys retrieved via WKD for import
-        std::transform(std::begin(keys), std::end(keys),
+        std::transform(std::begin(keys),
+                       std::end(keys),
                        std::inserter(keyListing.wkdKeyFingerprints, std::begin(keyListing.wkdKeyFingerprints)),
-                       [](const auto &k) { return k.primaryFingerprint(); });
+                       [](const auto &k) {
+                           return k.primaryFingerprint();
+                       });
     }
 
     tryToFinishKeyLookup();
 }
-#endif
 
 namespace
 {
@@ -446,18 +442,13 @@ void showKeysWithoutFingerprintsNotification(QWidget *parent, GpgME::Protocol pr
                          "<para>You may want to configure a different OpenPGP keyserver "
                          "in the configuration dialog.</para>");
     }
-    KMessageBox::information(parent, message, i18nc("@title", "Invalid Server Reply"),
-                             QStringLiteral("certificates-lookup-missing-fingerprints"));
+    KMessageBox::information(parent, message, i18nc("@title", "Invalid Server Reply"), QStringLiteral("certificates-lookup-missing-fingerprints"));
 }
 }
 
 void LookupCertificatesCommand::Private::tryToFinishKeyLookup()
 {
-    if (keyListing.cms || keyListing.openpgp
-#if QGPGME_SUPPORTS_WKDLOOKUP
-        || keyListing.wkdJob
-#endif
-    ) {
+    if (keyListing.cms || keyListing.openpgp || keyListing.wkdJob) {
         // still waiting for jobs to complete
         return;
     }
@@ -496,46 +487,34 @@ void LookupCertificatesCommand::Private::slotImportRequested(const std::vector<K
     dialog = nullptr;
 
     Q_ASSERT(!keys.empty());
-    Q_ASSERT(std::none_of(keys.cbegin(), keys.cend(), [](const Key &key) { return key.isNull(); }));
+    Q_ASSERT(std::none_of(keys.cbegin(), keys.cend(), [](const Key &key) {
+        return key.isNull();
+    }));
 
     std::vector<Key> wkdKeys, otherKeys;
     otherKeys.reserve(keys.size());
-    kdtools::separate_if(std::begin(keys), std::end(keys),
-                         std::back_inserter(wkdKeys),
-                         std::back_inserter(otherKeys),
-                         [this](const auto &key) {
-                             return key.primaryFingerprint() &&
-                                    keyListing.wkdKeyFingerprints.find(key.primaryFingerprint()) != std::end(keyListing.wkdKeyFingerprints);
-                         });
+    kdtools::separate_if(std::begin(keys), std::end(keys), std::back_inserter(wkdKeys), std::back_inserter(otherKeys), [this](const auto &key) {
+        return key.primaryFingerprint() && keyListing.wkdKeyFingerprints.find(key.primaryFingerprint()) != std::end(keyListing.wkdKeyFingerprints);
+    });
 
     std::vector<Key> pgp, cms;
     pgp.reserve(otherKeys.size());
     cms.reserve(otherKeys.size());
-    kdtools::separate_if(otherKeys.begin(), otherKeys.end(),
-                         std::back_inserter(pgp),
-                         std::back_inserter(cms),
-                         [](const Key &key) {
-                             return key.protocol() == GpgME::OpenPGP;
-                         });
+    kdtools::separate_if(otherKeys.begin(), otherKeys.end(), std::back_inserter(pgp), std::back_inserter(cms), [](const Key &key) {
+        return key.protocol() == GpgME::OpenPGP;
+    });
 
     setWaitForMoreJobs(true);
     if (!wkdKeys.empty()) {
         // set an import filter, so that only user IDs matching the email address used for the WKD lookup are imported
         const QString importFilter = QLatin1String{"keep-uid=mbox = "} + searchTextToEmailAddress(keyListing.pattern);
-        startImport(OpenPGP, keyListing.wkdKeyData, keyListing.wkdSource,
-                    {importFilter, Key::OriginWKD, keyListing.wkdSource});
+        startImport(OpenPGP, keyListing.wkdKeyData, keyListing.wkdSource, {importFilter, Key::OriginWKD, keyListing.wkdSource});
     }
     if (!pgp.empty()) {
-        startImport(OpenPGP, pgp,
-                    i18nc(R"(@title %1:"OpenPGP" or "S/MIME")",
-                          "%1 Certificate Server",
-                          Formatting::displayName(OpenPGP)));
+        startImport(OpenPGP, pgp, i18nc(R"(@title %1:"OpenPGP" or "S/MIME")", "%1 Certificate Server", Formatting::displayName(OpenPGP)));
     }
     if (!cms.empty()) {
-        startImport(CMS, cms,
-                    i18nc(R"(@title %1:"OpenPGP" or "S/MIME")",
-                          "%1 Certificate Server",
-                          Formatting::displayName(CMS)));
+        startImport(CMS, cms, i18nc(R"(@title %1:"OpenPGP" or "S/MIME")", "%1 Certificate Server", Formatting::displayName(CMS)));
     }
     setWaitForMoreJobs(false);
 }
@@ -567,9 +546,8 @@ void LookupCertificatesCommand::Private::showError(QWidget *parent, const KeyLis
     if (!result.error()) {
         return;
     }
-    KMessageBox::information(parent, i18nc("@info",
-                                           "Failed to search on certificate server. The error returned was:\n%1",
-                                           Formatting::errorAsString(result.error())));
+    KMessageBox::information(parent,
+                             i18nc("@info", "Failed to search on certificate server. The error returned was:\n%1", Formatting::errorAsString(result.error())));
 }
 
 void LookupCertificatesCommand::Private::showResult(QWidget *parent, const KeyListResult &result)
