@@ -8,8 +8,8 @@
 */
 
 #pragma once
-#include <kcmutils_version.h>
 #include <KCModule>
+#include <kcmutils_version.h>
 namespace Kleo
 {
 namespace Config
@@ -24,21 +24,15 @@ class CryptoOperationsConfigurationPage : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit CryptoOperationsConfigurationPage(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit CryptoOperationsConfigurationPage(QObject *parent, const KPluginMetaData &data = {}, const QVariantList &args = QVariantList());
-#endif
+    explicit CryptoOperationsConfigurationPage(QObject *parent, const KPluginMetaData &data = {});
 
-public Q_SLOTS:
     void load() override;
     void save() override;
     void defaults() override;
 
 private:
-    CryptoOperationsConfigWidget *mWidget;
+    CryptoOperationsConfigWidget *mWidget = nullptr;
 };
 
 }
 }
-
