@@ -23,22 +23,23 @@
 
 #include <Libkleo/ChecksumDefinition>
 #include <Libkleo/KeyFilterManager>
+#include <libkleo/classifyconfig.h>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KLocalizedString>
-#include <KSharedConfig>
 #include <KMessageBox>
+#include <KSharedConfig>
 
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDir>
 #include <QGroupBox>
 #include <QHBoxLayout>
-#include <QPushButton>
-#include <QVBoxLayout>
 #include <QLabel>
+#include <QPushButton>
 #include <QRegularExpression>
+#include <QVBoxLayout>
 
 #include <memory>
 
@@ -60,9 +61,11 @@ void CryptoOperationsConfigWidget::setupGui()
     auto fileGrpLay = new QVBoxLayout;
     mPGPFileExtCB = new QCheckBox(i18n(R"(Create OpenPGP encrypted files with ".pgp" file extensions instead of ".gpg")"));
     mASCIIArmorCB = new QCheckBox(i18n("Create signed or encrypted files as text files."));
-    mASCIIArmorCB->setToolTip(i18nc("@info", "Set this option to encode encrypted or signed files as base64 encoded text. "
-                                             "So that they can be opened with an editor or sent in a mail body. "
-                                             "This will increase file size by one third."));
+    mASCIIArmorCB->setToolTip(i18nc("@info",
+                                    "Set this option to encode encrypted or signed files as base64 encoded text. "
+                                    "So that they can be opened with an editor or sent in a mail body. "
+                                    "This will increase file size by one third."));
+    mTreatP7mEmailCB = new QCheckBox(i18nc("@option:check", "Treat .p7m files without extensions as mails."));
     mAutoDecryptVerifyCB = new QCheckBox(i18n("Automatically start operation based on input detection for decrypt/verify."));
     mAutoExtractArchivesCB = new QCheckBox(i18n("Automatically extract file archives after decryption"));
     mTmpDirCB = new QCheckBox(i18n("Create temporary decrypted files in the folder of the encrypted file."));
@@ -71,6 +74,7 @@ void CryptoOperationsConfigWidget::setupGui()
     mSymmetricOnlyCB->setToolTip(i18nc("@info", "Set this option to disable public key encryption."));
 
     fileGrpLay->addWidget(mPGPFileExtCB);
+    fileGrpLay->addWidget(mTreatP7mEmailCB);
     fileGrpLay->addWidget(mAutoDecryptVerifyCB);
     fileGrpLay->addWidget(mAutoExtractArchivesCB);
     fileGrpLay->addWidget(mASCIIArmorCB);
@@ -100,11 +104,13 @@ void CryptoOperationsConfigWidget::setupGui()
         connect(cb, &QCheckBox::toggled, this, &CryptoOperationsConfigWidget::changed);
     }
     for (auto combo : findChildren<QComboBox *>()) {
-        connect(combo, qOverload<int>(&QComboBox::currentIndexChanged), this, &CryptoOperationsConfigWidget::changed);
+        connect(combo, &QComboBox::currentIndexChanged, this, &CryptoOperationsConfigWidget::changed);
     }
 }
 
-CryptoOperationsConfigWidget::~CryptoOperationsConfigWidget() {}
+CryptoOperationsConfigWidget::~CryptoOperationsConfigWidget()
+{
+}
 
 void CryptoOperationsConfigWidget::defaults()
 {
@@ -117,14 +123,18 @@ void CryptoOperationsConfigWidget::defaults()
     filePrefs.setSymmetricEncryptionOnly(filePrefs.findItem(QStringLiteral("SymmetricEncryptionOnly"))->getDefault().toBool());
     filePrefs.setArchiveCommand(filePrefs.findItem(QStringLiteral("ArchiveCommand"))->getDefault().toString());
 
+    ClassifyConfig classifyConfig;
+    classifyConfig.setP7mWithoutExtensionAreEmail(classifyConfig.defaultP7mWithoutExtensionAreEmailValue());
+
     Settings settings;
     settings.setChecksumDefinitionId(settings.findItem(QStringLiteral("ChecksumDefinitionId"))->getDefault().toString());
 
-    load(filePrefs, settings);
+    load(filePrefs, settings, classifyConfig);
 }
 
 void CryptoOperationsConfigWidget::load(const Kleo::FileOperationsPreferences &filePrefs,
-                                        const Kleo::Settings &settings)
+                                        const Kleo::Settings &settings,
+                                        const Kleo::ClassifyConfig &classifyConfig)
 {
     mPGPFileExtCB->setChecked(filePrefs.usePGPFileExt());
     mPGPFileExtCB->setEnabled(!filePrefs.isImmutable(QStringLiteral("UsePGPFileExt")));
@@ -138,6 +148,7 @@ void CryptoOperationsConfigWidget::load(const Kleo::FileOperationsPreferences &f
     mTmpDirCB->setEnabled(!filePrefs.isImmutable(QStringLiteral("DontUseTmpDir")));
     mSymmetricOnlyCB->setChecked(filePrefs.symmetricEncryptionOnly());
     mSymmetricOnlyCB->setEnabled(!filePrefs.isImmutable(QStringLiteral("SymmetricEncryptionOnly")));
+    mTreatP7mEmailCB->setEnabled(!classifyConfig.isP7mWithoutExtensionAreEmailImmutable());
 
     const auto defaultChecksumDefinitionId = settings.checksumDefinitionId();
     {
@@ -162,7 +173,6 @@ void CryptoOperationsConfigWidget::load(const Kleo::FileOperationsPreferences &f
     mArchiveDefinitionCB.setEnabled(!filePrefs.isImmutable(QStringLiteral("ArchiveCommand")));
 }
 
-
 void CryptoOperationsConfigWidget::load()
 {
     mChecksumDefinitionCB.widget()->clear();
@@ -185,7 +195,7 @@ void CryptoOperationsConfigWidget::load()
         }
     }
 
-    load(FileOperationsPreferences{}, Settings{});
+    load(FileOperationsPreferences{}, Settings{}, ClassifyConfig{});
 }
 
 void CryptoOperationsConfigWidget::save()
@@ -212,4 +222,10 @@ void CryptoOperationsConfigWidget::save()
         filePrefs.setArchiveCommand(id);
     }
     filePrefs.save();
+
+    ClassifyConfig classifyConfig;
+    classifyConfig.setP7mWithoutExtensionAreEmail(mTreatP7mEmailCB->isChecked());
+    classifyConfig.save();
 }
+
+#include "moc_cryptooperationsconfigwidget.cpp"
