@@ -8,6 +8,7 @@
 */
 
 #include <config-kleopatra.h>
+
 #include "smimevalidationconfigurationpage.h"
 #include "smimevalidationconfigurationwidget.h"
 
@@ -15,26 +16,13 @@
 
 using namespace Kleo::Config;
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-SMimeValidationConfigurationPage::SMimeValidationConfigurationPage(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-SMimeValidationConfigurationPage::SMimeValidationConfigurationPage(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+SMimeValidationConfigurationPage::SMimeValidationConfigurationPage(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto lay = new QVBoxLayout(this);
-#else
     auto lay = new QVBoxLayout(widget());
-#endif
     lay->setContentsMargins(0, 0, 0, 0);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    mWidget = new SMimeValidationConfigurationWidget(this);
-#else
     mWidget = new SMimeValidationConfigurationWidget(widget());
-#endif
     lay->addWidget(mWidget);
 
     connect(mWidget, &SMimeValidationConfigurationWidget::changed, this, &Kleo::Config::SMimeValidationConfigurationPage::markAsChanged);
@@ -48,10 +36,11 @@ void SMimeValidationConfigurationPage::load()
 void SMimeValidationConfigurationPage::save()
 {
     mWidget->save();
-
 }
 
 void SMimeValidationConfigurationPage::defaults()
 {
     mWidget->defaults();
 }
+
+#include "moc_smimevalidationconfigurationpage.cpp"
