@@ -22,7 +22,6 @@
 
 #include <memory>
 
-
 namespace GpgME
 {
 class Key;
@@ -52,7 +51,7 @@ public:
         CombinedPGP,
         EncryptedPGP,
         EncryptedCMS,
-        Directory
+        Directory,
     };
 
     explicit SignEncryptFilesWizard(QWidget *parent = nullptr, Qt::WindowFlags f = {});
@@ -100,4 +99,3 @@ private:
 };
 
 }
-
