@@ -15,7 +15,7 @@
 
 #include <utils/pimpl_ptr.h>
 
-#include <KMime/HeaderParsing>
+#include <KMime/Types>
 #include <gpgme++/global.h>
 
 #include <memory>
@@ -27,7 +27,8 @@ class Key;
 }
 
 class QFileInfo;
-template <typename T> class QList;
+template<typename T>
+class QList;
 using QFileInfoList = QList<QFileInfo>;
 
 namespace Kleo
@@ -92,15 +93,13 @@ public:
 
     //@}
 
-    void setRecipients(const std::vector<KMime::Types::Mailbox> &recipients, const std::vector<KMime::Types::Mailbox> &encryptoToSelfRecipients);
-
     /** if true, the user is allowed to remove/add recipients via the UI.
      * Defaults to @p false.
      */
     bool recipientsUserMutable() const;
     void setRecipientsUserMutable(bool isMutable);
 
-    void setSignersAndCandidates(const std::vector<KMime::Types::Mailbox> &signers, const std::vector< std::vector<GpgME::Key> > &keys);
+    void setSignersAndCandidates(const std::vector<KMime::Types::Mailbox> &signers, const std::vector<std::vector<GpgME::Key>> &keys);
 
     void setTaskCollection(const std::shared_ptr<TaskCollection> &tasks);
 
@@ -137,4 +136,3 @@ private:
 }
 }
 }
-
