@@ -16,7 +16,8 @@
 
 #include <set>
 
-template <typename K, typename U> class QMap;
+template<typename K, typename U>
+class QMap;
 
 namespace GpgME
 {
@@ -25,6 +26,8 @@ class Key;
 
 namespace Kleo
 {
+struct CertificatePair;
+
 namespace Crypto
 {
 namespace Gui
@@ -39,9 +42,9 @@ public:
 
     void setAllowedProtocols(const std::set<GpgME::Protocol> &allowedProtocols);
     void setAllowedProtocols(bool pgp, bool cms);
-    void setSelectedCertificates(const QMap<GpgME::Protocol, GpgME::Key> &certificates);
+    void setSelectedCertificates(const CertificatePair &certificates);
     void setSelectedCertificates(const GpgME::Key &pgp, const GpgME::Key &cms);
-    QMap<GpgME::Protocol, GpgME::Key> selectedCertificates() const;
+    CertificatePair selectedCertificates() const;
 
     bool rememberAsDefault() const;
 
@@ -53,5 +56,3 @@ private:
 }
 }
 }
-
-
