@@ -11,28 +11,29 @@
 
 #include "verifychecksumscontroller.h"
 
+#include "checksumsutils_p.h"
+
 #ifndef QT_NO_DIRMODEL
 
 #include <crypto/gui/verifychecksumsdialog.h>
 
 #include <utils/input.h>
-#include <utils/output.h>
 #include <utils/kleo_assert.h>
+#include <utils/output.h>
 
-#include <Libkleo/Stl_Util>
 #include <Libkleo/ChecksumDefinition>
 #include <Libkleo/Classify>
+#include <Libkleo/Stl_Util>
 
 #include <KLocalizedString>
 
-#include "kleopatra_debug.h"
-#include <QPointer>
-#include <QFileInfo>
-#include <QThread>
-#include <QMutex>
-#include <QProgressDialog>
 #include <QDir>
+#include <QFileInfo>
+#include <QMutex>
+#include <QPointer>
 #include <QProcess>
+#include <QProgressDialog>
+#include <QThread>
 
 #include <gpg-error.h>
 
@@ -44,23 +45,13 @@ using namespace Kleo;
 using namespace Kleo::Crypto;
 using namespace Kleo::Crypto::Gui;
 
-#ifdef Q_OS_UNIX
-static const bool HAVE_UNIX = true;
-#else
-static const bool HAVE_UNIX = false;
-#endif
-
-static const QLatin1String CHECKSUM_DEFINITION_ID_ENTRY("checksum-definition-id");
-
-static const Qt::CaseSensitivity fs_cs = HAVE_UNIX ? Qt::CaseSensitive : Qt::CaseInsensitive; // can we use QAbstractFileEngine::caseSensitive()?
-
 #if 0
 static QStringList fs_sort(QStringList l)
 {
     int (*QString_compare)(const QString &, const QString &, Qt::CaseSensitivity) = &QString::compare;
     std::sort(l.begin(), l.end(),
               [](const QString &lhs, const QString &rhs) {
-                return QString::compare(lhs, rhs, fs_cs) < 0;
+                return QString::compare(lhs, rhs, ChecksumsUtils::fs_cs) < 0;
               });
     return l;
 }
@@ -75,43 +66,25 @@ static QStringList fs_intersect(QStringList l1, QStringList l2)
                           l2.begin(), l2.end(),
                           std::back_inserter(result),
                           [](const QString &lhs, const QString &rhs) {
-                            return QString::compare(lhs, rhs, fs_cs) < 0;
+                            return QString::compare(lhs, rhs, ChecksumsUtils::fs_cs) < 0;
                           });
     return result;
 }
 #endif
 
-static QList<QRegExp> get_patterns(const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
-{
-    QList<QRegExp> result;
-    for (const std::shared_ptr<ChecksumDefinition> &cd : checksumDefinitions)
-        if (cd) {
-            const auto patterns = cd->patterns();
-            for (const QString &pattern : patterns) {
-                result.push_back(QRegExp(pattern, fs_cs));
-            }
-        }
-    return result;
-}
-
 namespace
 {
-struct matches_any : std::unary_function<QString, bool> {
-    const QList<QRegExp> m_regexps;
-    explicit matches_any(const QList<QRegExp> &regexps) : m_regexps(regexps) {}
-    bool operator()(const QString &s) const
+struct matches_none_of {
+    const std::vector<QRegularExpression> m_regexps;
+    explicit matches_none_of(const std::vector<QRegularExpression> &regexps)
+        : m_regexps(regexps)
     {
-        return std::any_of(m_regexps.cbegin(), m_regexps.cend(),
-                           [&s](const QRegExp &rx) { return rx.exactMatch(s); });
     }
-};
-struct matches_none_of : std::unary_function<QString, bool> {
-    const QList<QRegExp> m_regexps;
-    explicit matches_none_of(const QList<QRegExp> &regexps) : m_regexps(regexps) {}
     bool operator()(const QString &s) const
     {
-        return std::none_of(m_regexps.cbegin(), m_regexps.cend(),
-                            [&s](const QRegExp &rx) { return rx.exactMatch(s); });
+        return std::none_of(m_regexps.cbegin(), m_regexps.cend(), [&s](const QRegularExpression &rx) {
+            return rx.match(s).hasMatch();
+        });
     }
 };
 }
@@ -121,6 +94,7 @@ class VerifyChecksumsController::Private : public QThread
     Q_OBJECT
     friend class ::Kleo::Crypto::VerifyChecksumsController;
     VerifyChecksumsController *const q;
+
 public:
     explicit Private(VerifyChecksumsController *qq);
     ~Private() override;
@@ -139,8 +113,7 @@ private:
         }
 
         if (!errors.empty())
-            q->setLastError(gpg_error(GPG_ERR_GENERAL),
-                            errors.join(QLatin1Char('\n')));
+            q->setLastError(gpg_error(GPG_ERR_GENERAL), errors.join(QLatin1Char('\n')));
         q->emitDoneOrError();
     }
 
@@ -150,25 +123,23 @@ private:
 private:
     QPointer<VerifyChecksumsDialog> dialog;
     mutable QMutex mutex;
-    const std::vector< std::shared_ptr<ChecksumDefinition> > checksumDefinitions;
+    const std::vector<std::shared_ptr<ChecksumDefinition>> checksumDefinitions;
     QStringList files;
     QStringList errors;
     volatile bool canceled;
 };
 
 VerifyChecksumsController::Private::Private(VerifyChecksumsController *qq)
-    : q(qq),
-      dialog(),
-      mutex(),
-      checksumDefinitions(ChecksumDefinition::getChecksumDefinitions()),
-      files(),
-      errors(),
-      canceled(false)
+    : q(qq)
+    , dialog()
+    , mutex()
+    , checksumDefinitions(ChecksumDefinition::getChecksumDefinitions())
+    , files()
+    , errors()
+    , canceled(false)
 {
-    connect(this, &Private::progress,
-            q, &Controller::progress);
-    connect(this, SIGNAL(finished()),
-            q, SLOT(slotOperationFinished()));
+    connect(this, &Private::progress, q, &Controller::progress);
+    connect(this, SIGNAL(finished()), q, SLOT(slotOperationFinished()));
 }
 
 VerifyChecksumsController::Private::~Private()
@@ -177,15 +148,15 @@ VerifyChecksumsController::Private::~Private()
 }
 
 VerifyChecksumsController::VerifyChecksumsController(QObject *p)
-    : Controller(p), d(new Private(this))
+    : Controller(p)
+    , d(new Private(this))
 {
-
 }
 
 VerifyChecksumsController::VerifyChecksumsController(const std::shared_ptr<const ExecutionContext> &ctx, QObject *p)
-    : Controller(ctx, p), d(new Private(this))
+    : Controller(ctx, p)
+    , d(new Private(this))
 {
-
 }
 
 VerifyChecksumsController::~VerifyChecksumsController()
@@ -203,7 +174,6 @@ void VerifyChecksumsController::setFiles(const QStringList &files)
 
 void VerifyChecksumsController::start()
 {
-
     {
         const QMutexLocker locker(&d->mutex);
 
@@ -211,14 +181,10 @@ void VerifyChecksumsController::start()
         d->dialog->setAttribute(Qt::WA_DeleteOnClose);
         d->dialog->setWindowTitle(i18nc("@title:window", "Verify Checksum Results"));
 
-        connect(d->dialog.data(), &VerifyChecksumsDialog::canceled,
-                this, &VerifyChecksumsController::cancel);
-        connect(d.get(), &Private::baseDirectories,
-                d->dialog.data(), &VerifyChecksumsDialog::setBaseDirectories);
-        connect(d.get(), &Private::progress,
-                d->dialog.data(), &VerifyChecksumsDialog::setProgress);
-        connect(d.get(), &Private::status,
-                d->dialog.data(), &VerifyChecksumsDialog::setStatus);
+        connect(d->dialog.data(), &VerifyChecksumsDialog::canceled, this, &VerifyChecksumsController::cancel);
+        connect(d.get(), &Private::baseDirectories, d->dialog.data(), &VerifyChecksumsDialog::setBaseDirectories);
+        connect(d.get(), &Private::progress, d->dialog.data(), &VerifyChecksumsDialog::setProgress);
+        connect(d.get(), &Private::status, d->dialog.data(), &VerifyChecksumsDialog::setStatus);
 
         d->canceled = false;
         d->errors.clear();
@@ -227,7 +193,6 @@ void VerifyChecksumsController::start()
     d->start();
 
     d->dialog->show();
-
 }
 
 void VerifyChecksumsController::cancel()
@@ -249,72 +214,12 @@ struct SumFile {
 
 }
 
-static QStringList filter_checksum_files(QStringList l, const QList<QRegExp> &rxs)
+static QStringList filter_checksum_files(QStringList l, const std::vector<QRegularExpression> &rxs)
 {
-    l.erase(std::remove_if(l.begin(), l.end(),
-                           matches_none_of(rxs)),
-            l.end());
+    l.erase(std::remove_if(l.begin(), l.end(), matches_none_of(rxs)), l.end());
     return l;
 }
 
-namespace
-{
-struct File {
-    QString name;
-    QByteArray checksum;
-    bool binary;
-};
-}
-
-static QString decode(const QString &encoded)
-{
-    QString decoded;
-    decoded.reserve(encoded.size());
-    bool shift = false;
-    for (const QChar &ch : encoded)
-        if (shift) {
-            switch (ch.toLatin1()) {
-            case '\\': decoded += QLatin1Char('\\'); break;
-            case 'n':  decoded += QLatin1Char('\n'); break;
-            default:
-                qCDebug(KLEOPATRA_LOG) << "invalid escape sequence" << '\\' << ch << "(interpreted as '" << ch << "')";
-                decoded += ch;
-                break;
-            }
-            shift = false;
-        } else {
-            if (ch == QLatin1Char('\\')) {
-                shift = true;
-            } else {
-                decoded += ch;
-            }
-        }
-    return decoded;
-}
-
-static std::vector<File> parse_sum_file(const QString &fileName)
-{
-    std::vector<File> files;
-    QFile f(fileName);
-    if (f.open(QIODevice::ReadOnly)) {
-        QTextStream s(&f);
-        QRegExp rx(QLatin1String("(\\?)([a-f0-9A-F]+) ([ *])([^\n]+)\n*"));
-        while (!s.atEnd()) {
-            const QString line = s.readLine();
-            if (rx.exactMatch(line)) {
-                Q_ASSERT(!rx.cap(4).endsWith(QLatin1Char('\n')));
-                const File file = {
-                    rx.cap(1) == QLatin1String("\\") ? decode(rx.cap(4)) : rx.cap(4),
-                    rx.cap(2).toLatin1(),
-                    rx.cap(3) == QLatin1String("*"),
-                };
-                files.push_back(file);
-            }
-        }
-    }
-    return files;
-}
-
 static quint64 aggregate_size(const QDir &dir, const QStringList &files)
 {
     quint64 n = 0;
@@ -324,50 +229,35 @@ static quint64 aggregate_size(const QDir &dir, const QStringList &files)
     return n;
 }
 
-static std::shared_ptr<ChecksumDefinition> filename2definition(const QString &fileName,
-        const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
-{
-    for (const std::shared_ptr<ChecksumDefinition> &cd : checksumDefinitions)
-        if (cd) {
-            const auto patterns = cd->patterns();
-            for (const QString &pattern : patterns)
-                if (QRegExp(pattern, fs_cs).exactMatch(fileName)) {
-                    return cd;
-                }
-        }
-    return std::shared_ptr<ChecksumDefinition>();
-}
-
 namespace
 {
-struct less_dir : std::binary_function<QDir, QDir, bool> {
+struct less_dir {
     bool operator()(const QDir &lhs, const QDir &rhs) const
     {
-        return QString::compare(lhs.absolutePath(), rhs.absolutePath(), fs_cs) < 0;
+        return QString::compare(lhs.absolutePath(), rhs.absolutePath(), ChecksumsUtils::fs_cs) < 0;
     }
 };
-struct less_file : std::binary_function<QString, QString, bool> {
+struct less_file {
     bool operator()(const QString &lhs, const QString &rhs) const
     {
-        return QString::compare(lhs, rhs, fs_cs) < 0;
+        return QString::compare(lhs, rhs, ChecksumsUtils::fs_cs) < 0;
     }
 };
-struct sumfile_contains_file : std::unary_function<QString, bool> {
+struct sumfile_contains_file {
     const QDir dir;
     const QString fileName;
     sumfile_contains_file(const QDir &dir_, const QString &fileName_)
-        : dir(dir_), fileName(fileName_) {}
+        : dir(dir_)
+        , fileName(fileName_)
+    {
+    }
     bool operator()(const QString &sumFile) const
     {
-        const std::vector<File> files = parse_sum_file(dir.absoluteFilePath(sumFile));
-        qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:      found " << files.size()
-                               << " files listed in " << qPrintable(dir.absoluteFilePath(sumFile));
-        for (const File &file : files) {
-            const bool isSameFileName = (QString::compare(file.name, fileName, fs_cs) == 0);
-            qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:        "
-                                   << qPrintable(file.name) << " == "
-                                   << qPrintable(fileName)  << " ? "
-                                   << isSameFileName;
+        const std::vector<ChecksumsUtils::File> files = ChecksumsUtils::parse_sum_file(dir.absoluteFilePath(sumFile));
+        qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:      found " << files.size() << " files listed in " << qPrintable(dir.absoluteFilePath(sumFile));
+        for (const ChecksumsUtils::File &file : files) {
+            const bool isSameFileName = (QString::compare(file.name, fileName, ChecksumsUtils::fs_cs) == 0);
+            qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:        " << qPrintable(file.name) << " == " << qPrintable(fileName) << " ? " << isSameFileName;
             if (isSameFileName) {
                 return true;
             }
@@ -375,7 +265,6 @@ struct sumfile_contains_file : std::unary_function<QString, bool> {
         return false;
     }
 };
-
 }
 
 // IF is_dir(file)
@@ -390,7 +279,6 @@ struct sumfile_contains_file : std::unary_function<QString, bool> {
 
 static QStringList find_base_directories(const QStringList &files)
 {
-
     // Step 1: find base dirs:
 
     std::set<QDir, less_dir> dirs;
@@ -423,13 +311,14 @@ static QStringList find_base_directories(const QStringList &files)
     return rv;
 }
 
-static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, QStringList &errors,
-        const std::function<void(int)> &progress,
-        const std::vector< std::shared_ptr<ChecksumDefinition> > &checksumDefinitions)
+static std::vector<SumFile> find_sums_by_input_files(const QStringList &files,
+                                                     QStringList &errors,
+                                                     const std::function<void(int)> &progress,
+                                                     const std::vector<std::shared_ptr<ChecksumDefinition>> &checksumDefinitions)
 {
-    const QList<QRegExp> patterns = get_patterns(checksumDefinitions);
+    const std::vector<QRegularExpression> patterns = ChecksumsUtils::get_patterns(checksumDefinitions);
 
-    const matches_any is_sum_file(patterns);
+    const ChecksumsUtils::matches_any is_sum_file(patterns);
 
     std::map<QDir, std::set<QString, less_file>, less_dir> dirs2sums;
 
@@ -450,15 +339,12 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
             const QStringList sumfiles = filter_checksum_files(dir.entryList(QDir::Files), patterns);
             qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:   found " << sumfiles.size()
                                    << " sum files: " << qPrintable(sumfiles.join(QLatin1String(", ")));
-            dirs2sums[ dir ].insert(sumfiles.begin(), sumfiles.end());
+            dirs2sums[dir].insert(sumfiles.begin(), sumfiles.end());
             const QStringList dirs = dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot);
-            qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:   found " << dirs.size()
-                                   << " subdirs, prepending";
-            std::transform(dirs.cbegin(), dirs.cend(),
-                           std::inserter(inputs, inputs.begin()),
-                           [&dir](const QString &path) {
-                               return dir.absoluteFilePath(path);
-                           });
+            qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:   found " << dirs.size() << " subdirs, prepending";
+            std::transform(dirs.cbegin(), dirs.cend(), std::inserter(inputs, inputs.begin()), [&dir](const QString &path) {
+                return dir.absoluteFilePath(path);
+            });
         } else if (is_sum_file(fileName)) {
             qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:   it's a sum file";
             dirs2sums[fi.dir()].insert(fileName);
@@ -468,8 +354,7 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
             const QStringList sumfiles = filter_checksum_files(dir.entryList(QDir::Files), patterns);
             qCDebug(KLEOPATRA_LOG) << "find_sums_by_input_files:   found " << sumfiles.size()
                                    << " potential sumfiles: " << qPrintable(sumfiles.join(QLatin1String(", ")));
-            const auto it = std::find_if(sumfiles.cbegin(), sumfiles.cend(),
-                                         sumfile_contains_file(dir, fileName));
+            const auto it = std::find_if(sumfiles.cbegin(), sumfiles.cend(), sumfile_contains_file(dir, fileName));
             if (it == sumfiles.end()) {
                 errors.push_back(i18n("Cannot find checksums file for file %1", file));
             } else {
@@ -487,7 +372,6 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
     sumfiles.reserve(dirs2sums.size());
 
     for (auto it = dirs2sums.begin(), end = dirs2sums.end(); it != end; ++it) {
-
         if (it->second.empty()) {
             continue;
         }
@@ -495,36 +379,34 @@ static std::vector<SumFile> find_sums_by_input_files(const QStringList &files, Q
         const QDir &dir = it->first;
 
         for (const QString &sumFileName : std::as_const(it->second)) {
-
-            const std::vector<File> summedfiles = parse_sum_file(dir.absoluteFilePath(sumFileName));
+            const std::vector<ChecksumsUtils::File> summedfiles = ChecksumsUtils::parse_sum_file(dir.absoluteFilePath(sumFileName));
             QStringList files;
             files.reserve(summedfiles.size());
-            std::transform(summedfiles.cbegin(), summedfiles.cend(),
-                           std::back_inserter(files), std::mem_fn(&File::name));
+            std::transform(summedfiles.cbegin(), summedfiles.cend(), std::back_inserter(files), std::mem_fn(&ChecksumsUtils::File::name));
             const SumFile sumFile = {
                 it->first,
                 sumFileName,
                 aggregate_size(it->first, files),
-                filename2definition(sumFileName, checksumDefinitions),
+                ChecksumsUtils::filename2definition(sumFileName, checksumDefinitions),
             };
             sumfiles.push_back(sumFile);
-
         }
 
         if (progress) {
             progress(++i);
         }
-
     }
     return sumfiles;
 }
 
 static QStringList c_lang_environment()
 {
+    static const QRegularExpression re(QRegularExpression::anchoredPattern(u"LANG=.*"), ChecksumsUtils::s_regex_cs);
     QStringList env = QProcess::systemEnvironment();
-    env.erase(std::remove_if(env.begin(), env.end(),
+    env.erase(std::remove_if(env.begin(),
+                             env.end(),
                              [](const QString &str) {
-                                 return QRegExp(QLatin1String("^LANG=.*"), fs_cs).exactMatch(str);
+                                 return re.match(str).hasMatch();
                              }),
               env.end());
     env.push_back(QStringLiteral("LANG=C"));
@@ -535,10 +417,10 @@ static const struct {
     const char *string;
     VerifyChecksumsDialog::Status status;
 } statusStrings[] = {
-    { "OK",     VerifyChecksumsDialog::OK     },
-    { "FAILED", VerifyChecksumsDialog::Failed },
+    {"OK", VerifyChecksumsDialog::OK},
+    {"FAILED", VerifyChecksumsDialog::Failed},
 };
-static const size_t numStatusStrings = sizeof statusStrings / sizeof * statusStrings;
+static const size_t numStatusStrings = sizeof statusStrings / sizeof *statusStrings;
 
 static VerifyChecksumsDialog::Status string2status(const QByteArray &str)
 {
@@ -549,8 +431,8 @@ static VerifyChecksumsDialog::Status string2status(const QByteArray &str)
     return VerifyChecksumsDialog::Unknown;
 }
 
-static QString process(const SumFile &sumFile, bool *fatal, const QStringList &env,
-                       const std::function<void(const QString &, VerifyChecksumsDialog::Status)> &status)
+static QString
+process(const SumFile &sumFile, bool *fatal, const QStringList &env, const std::function<void(const QString &, VerifyChecksumsDialog::Status)> &status)
 {
     QProcess p;
     p.setEnvironment(env);
@@ -572,7 +454,11 @@ static QString process(const SumFile &sumFile, bool *fatal, const QStringList &e
                 remainder += line; // no colon -> probably filename with a newline
                 continue;
             }
+#ifdef Q_OS_WIN
+            const QString file = QString::fromUtf8(remainder + line.left(colonIdx));
+#else
             const QString file = QFile::decodeName(remainder + line.left(colonIdx));
+#endif
             remainder.clear();
             const VerifyChecksumsDialog::Status result = string2status(line.mid(colonIdx + 1).trimmed());
             status(sumFile.dir.absoluteFilePath(file), result);
@@ -585,8 +471,7 @@ static QString process(const SumFile &sumFile, bool *fatal, const QStringList &e
             *fatal = true;
         }
         if (p.error() == QProcess::UnknownError)
-            return i18n("Error while running %1: %2", program,
-                        QString::fromLocal8Bit(p.readAllStandardError().trimmed().constData()));
+            return i18n("Error while running %1: %2", program, QString::fromLocal8Bit(p.readAllStandardError().trimmed().constData()));
         else {
             return i18n("Failed to execute %1: %2", program, p.errorString());
         }
@@ -605,11 +490,10 @@ static QDebug operator<<(QDebug s, const SumFile &sum)
 
 void VerifyChecksumsController::Private::run()
 {
-
     QMutexLocker locker(&mutex);
 
     const QStringList files = this->files;
-    const std::vector< std::shared_ptr<ChecksumDefinition> > checksumDefinitions = this->checksumDefinitions;
+    const std::vector<std::shared_ptr<ChecksumDefinition>> checksumDefinitions = this->checksumDefinitions;
 
     locker.unlock();
 
@@ -628,8 +512,12 @@ void VerifyChecksumsController::Private::run()
     const QString scanning = i18n("Scanning directories...");
     Q_EMIT progress(0, 0, scanning);
 
-    const auto progressCb = [this, scanning](int arg) { Q_EMIT progress(arg, 0, scanning); };
-    const auto statusCb = [this](const QString &str, VerifyChecksumsDialog::Status st) { Q_EMIT status(str, st); };
+    const auto progressCb = [this, scanning](int arg) {
+        Q_EMIT progress(arg, 0, scanning);
+    };
+    const auto statusCb = [this](const QString &str, VerifyChecksumsDialog::Status st) {
+        Q_EMIT status(str, st);
+    };
 
     const std::vector<SumFile> sumfiles = find_sums_by_input_files(files, errors, progressCb, checksumDefinitions);
 
@@ -638,15 +526,11 @@ void VerifyChecksumsController::Private::run()
     }
 
     if (!canceled) {
-
         Q_EMIT progress(0, 0, i18n("Calculating total size..."));
 
-        const quint64 total
-            = kdtools::accumulate_transform(sumfiles.cbegin(), sumfiles.cend(),
-                                            std::mem_fn(&SumFile::totalSize), Q_UINT64_C(0));
+        const quint64 total = kdtools::accumulate_transform(sumfiles.cbegin(), sumfiles.cend(), std::mem_fn(&SumFile::totalSize), Q_UINT64_C(0));
 
         if (!canceled) {
-
             //
             // Step 2: perform work (with progress reporting):
             //
@@ -658,8 +542,7 @@ void VerifyChecksumsController::Private::run()
 
             quint64 done = 0;
             for (const SumFile &sumFile : sumfiles) {
-                Q_EMIT progress(done / factor, total / factor,
-                                i18n("Verifying checksums (%2) in %1", sumFile.checksumDefinition->label(), sumFile.dir.path()));
+                Q_EMIT progress(done / factor, total / factor, i18n("Verifying checksums (%2) in %1", sumFile.checksumDefinition->label(), sumFile.dir.path()));
                 bool fatal = false;
                 const QString error = process(sumFile, &fatal, env, statusCb);
                 if (!error.isEmpty()) {
@@ -671,7 +554,6 @@ void VerifyChecksumsController::Private::run()
                 }
             }
             Q_EMIT progress(done / factor, total / factor, i18n("Done."));
-
         }
     }
 
@@ -680,7 +562,6 @@ void VerifyChecksumsController::Private::run()
     this->errors = errors;
 
     // mutex unlocked by QMutexLocker
-
 }
 
 #include "moc_verifychecksumscontroller.cpp"
