@@ -7,31 +7,31 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef QT_NO_CAST_TO_ASCII
-# define QT_NO_CAST_TO_ASCII
+#define QT_NO_CAST_TO_ASCII
 #endif
 #ifndef QT_NO_CAST_FROM_ASCII
-# define QT_NO_CAST_FROM_ASCII
+#define QT_NO_CAST_FROM_ASCII
 #endif
 
 #include <config-kleopatra.h>
 #include <version-kleopatra.h>
 
-#include "assuanserverconnection.h"
 #include "assuancommand.h"
+#include "assuanserverconnection.h"
 #include "sessiondata.h"
 
-#include <utils/input.h>
-#include <utils/output.h>
 #include <utils/detail_p.h>
-#include <utils/log.h>
+#include <utils/input.h>
 #include <utils/kleo_assert.h>
+#include <utils/log.h>
+#include <utils/output.h>
 
 #include <Libkleo/Formatting>
 #include <Libkleo/GnuPG>
 #include <Libkleo/Hex>
-#include <Libkleo/Stl_Util>
-#include <Libkleo/KleoException>
 #include <Libkleo/KeyCache>
+#include <Libkleo/KleoException>
+#include <Libkleo/Stl_Util>
 
 #include <gpgme++/data.h>
 #include <gpgme++/key.h>
@@ -42,39 +42,38 @@
 #include <KLocalizedString>
 #include <KWindowSystem>
 
+#include <QCoreApplication>
+#include <QFileInfo>
+#include <QPointer>
+#include <QRegularExpression>
 #include <QSocketNotifier>
+#include <QStringList>
 #include <QTimer>
 #include <QVariant>
-#include <QPointer>
-#include <QFileInfo>
-#include <QStringList>
-#include <QRegularExpression>
 #include <QWidget>
-#include <QCoreApplication>
 
-
-#include <map>
 #include <algorithm>
 #include <functional>
+#include <map>
 #include <type_traits>
 
 #include <cerrno>
 
 #ifdef __GLIBCXX__
-# include <ext/algorithm> // for is_sorted
+#include <ext/algorithm> // for is_sorted
 #endif
 
 #ifdef Q_OS_WIN
-# include <io.h>
-# include <process.h>
+#include <io.h>
+#include <process.h>
 #else
-# include <sys/types.h>
-# include <unistd.h>
+#include <sys/types.h>
+#include <unistd.h>
 #endif
 using namespace Kleo;
 
 static const unsigned int INIT_SOCKET_FLAGS = 3; // says info assuan...
-//static int(*USE_DEFAULT_HANDLER)(assuan_context_t,char*) = 0;
+// static int(*USE_DEFAULT_HANDLER)(assuan_context_t,char*) = 0;
 static const int FOR_READING = 0;
 static const unsigned int MAX_ACTIVE_FDS = 32;
 
@@ -88,8 +87,14 @@ static void my_assuan_release(assuan_context_t ctx)
 // std::shared_ptr for assuan_context_t w/ deleter enforced to assuan_deinit_server:
 using AssuanContextBase = std::shared_ptr<std::remove_pointer<assuan_context_t>::type>;
 struct AssuanContext : AssuanContextBase {
-    AssuanContext() : AssuanContextBase() {}
-    explicit AssuanContext(assuan_context_t ctx) : AssuanContextBase(ctx, &my_assuan_release) {}
+    AssuanContext()
+        : AssuanContextBase()
+    {
+    }
+    explicit AssuanContext(assuan_context_t ctx)
+        : AssuanContextBase(ctx, &my_assuan_release)
+    {
+    }
 
     void reset(assuan_context_t ctx = nullptr)
     {
@@ -102,11 +107,6 @@ static inline gpg_error_t assuan_process_done_msg(assuan_context_t ctx, gpg_erro
     return assuan_process_done(ctx, assuan_set_error(ctx, err, err_msg));
 }
 
-static inline gpg_error_t assuan_process_done_msg(assuan_context_t ctx, gpg_error_t err, const std::string &err_msg)
-{
-    return assuan_process_done_msg(ctx, err, err_msg.c_str());
-}
-
 static inline gpg_error_t assuan_process_done_msg(assuan_context_t ctx, gpg_error_t err, const QString &err_msg)
 {
     return assuan_process_done_msg(ctx, err, err_msg.toUtf8().constData());
@@ -141,19 +141,18 @@ static std::map<std::string, std::string> parse_commandline(const char *line)
             if (*line == ' ' || *line == '\t') {
                 if (begin != line) {
                     if (begin[0] == '-' && begin[1] == '-') {
-                        begin += 2;    // skip initial "--"
+                        begin += 2; // skip initial "--"
                     }
                     if (lastEQ && lastEQ > begin) {
-                        result[ std::string(begin, lastEQ - begin) ] = hexdecode(std::string(lastEQ + 1, line - (lastEQ + 1)));
+                        result[std::string(begin, lastEQ - begin)] = hexdecode(std::string(lastEQ + 1, line - (lastEQ + 1)));
                     } else {
-                        result[ std::string(begin,  line  - begin) ] = std::string();
+                        result[std::string(begin, line - begin)] = std::string();
                     }
                 }
                 begin = line + 1;
             } else if (*line == '=') {
                 if (line == begin)
-                    throw Exception(gpg_error(GPG_ERR_ASS_SYNTAX),
-                                    i18n("No option name given"));
+                    throw Exception(gpg_error(GPG_ERR_ASS_SYNTAX), i18n("No option name given"));
                 else {
                     lastEQ = line;
                 }
@@ -162,12 +161,12 @@ static std::map<std::string, std::string> parse_commandline(const char *line)
         }
         if (begin != line) {
             if (begin[0] == '-' && begin[1] == '-') {
-                begin += 2;    // skip initial "--"
+                begin += 2; // skip initial "--"
             }
             if (lastEQ && lastEQ > begin) {
-                result[ std::string(begin, lastEQ - begin) ] = hexdecode(std::string(lastEQ + 1, line - (lastEQ + 1)));
+                result[std::string(begin, lastEQ - begin)] = hexdecode(std::string(lastEQ + 1, line - (lastEQ + 1)));
             } else {
-                result[ begin ] = std::string();
+                result[begin] = std::string();
             }
         }
     }
@@ -212,8 +211,9 @@ class AssuanServerConnection::Private : public QObject
     friend class ::Kleo::AssuanCommandFactory;
     friend class ::Kleo::AssuanCommand;
     AssuanServerConnection *const q;
+
 public:
-    Private(assuan_fd_t fd_, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq);
+    Private(assuan_fd_t fd_, const std::vector<std::shared_ptr<AssuanCommandFactory>> &factories_, AssuanServerConnection *qq);
     ~Private() override;
 
 Q_SIGNALS:
@@ -225,14 +225,14 @@ public Q_SLOTS:
         Q_ASSERT(ctx);
         int done = false;
         if (const int err = assuan_process_next(ctx.get(), &done) || done) {
-            //if ( err == -1 || gpg_err_code(err) == GPG_ERR_EOF ) {
+            // if ( err == -1 || gpg_err_code(err) == GPG_ERR_EOF ) {
             topHalfDeletion();
             if (nohupedCommands.empty()) {
                 bottomHalfDeletion();
             }
             //} else {
-            //assuan_process_done( ctx.get(), err );
-            //return;
+            // assuan_process_done( ctx.get(), err );
+            // return;
             //}
         }
     }
@@ -242,10 +242,9 @@ public Q_SLOTS:
 private:
     void nohupDone(AssuanCommand *cmd)
     {
-        const auto it = std::find_if(nohupedCommands.begin(), nohupedCommands.end(),
-                                     [cmd](const std::shared_ptr<AssuanCommand> &other) {
-                                        return other.get() == cmd;
-                                     });
+        const auto it = std::find_if(nohupedCommands.begin(), nohupedCommands.end(), [cmd](const std::shared_ptr<AssuanCommand> &other) {
+            return other.get() == cmd;
+        });
         Q_ASSERT(it != nohupedCommands.end());
         nohupedCommands.erase(it);
         if (nohupedCommands.empty() && closed) {
@@ -309,12 +308,12 @@ private:
         AssuanServerConnection::Private &conn = *static_cast<AssuanServerConnection::Private *>(assuan_get_pointer(ctx_));
 
         if (key && key[0] == '-' && key[1] == '-') {
-            key += 2;    // skip "--"
+            key += 2; // skip "--"
         }
         conn.options[key] = QString::fromUtf8(value);
 
         return 0;
-        //return gpg_error( GPG_ERR_UNKNOWN_OPTION );
+        // return gpg_error( GPG_ERR_UNKNOWN_OPTION );
     }
 
     static gpg_error_t session_handler(assuan_context_t ctx_, char *line)
@@ -345,8 +344,7 @@ private:
             conn.sessionTitle = cap2;
         }
         qCDebug(KLEOPATRA_LOG) << "session_handler: "
-                               << "id=" << static_cast<unsigned long>(conn.sessionId)
-                               << ", title=" << qPrintable(conn.sessionTitle);
+                               << "id=" << static_cast<unsigned long>(conn.sessionId) << ", title=" << qPrintable(conn.sessionTitle);
         return assuan_process_done(ctx_, 0);
     }
 
@@ -359,8 +357,7 @@ private:
         static const char capabilities[] =
             "SENDER=info\n"
             "RECIPIENT=info\n"
-            "SESSION\n"
-            ;
+            "SESSION\n";
         return assuan_process_done(ctx_, assuan_send_data(ctx_, capabilities, sizeof capabilities - 1));
     }
 
@@ -424,11 +421,12 @@ private:
         return assuan_process_done(ctx_, 0);
     }
 
-    template <bool in>
-    struct Input_or_Output : std::conditional<in, Input, Output> {};
+    template<bool in>
+    struct Input_or_Output : std::conditional<in, Input, Output> {
+    };
 
     // format: TAG (FD|FD=\d+|FILE=...)
-    template <bool in, typename T_memptr>
+    template<bool in, typename T_memptr>
     static gpg_error_t IO_handler(assuan_context_t ctx_, char *line_, T_memptr which)
     {
         Q_ASSERT(assuan_get_pointer(ctx_));
@@ -444,16 +442,14 @@ private:
         }
 
         try {
-
             /*const*/ std::map<std::string, std::string> options = upcase_option("FD", upcase_option("FILE", parse_commandline(line_)));
             if (options.size() < 1 || options.size() > 2) {
                 throw gpg_error(GPG_ERR_ASS_SYNTAX);
             }
 
-            std::shared_ptr< typename Input_or_Output<in>::type > io;
+            std::shared_ptr<typename Input_or_Output<in>::type> io;
 
             if (options.count("FD")) {
-
                 if (options.count("FILE")) {
                     throw gpg_error(GPG_ERR_CONFLICT);
                 }
@@ -479,7 +475,6 @@ private:
                 options.erase("FD");
 
             } else if (options.count("FILE")) {
-
                 if (options.count("FD")) {
                     throw gpg_error(GPG_ERR_CONFLICT);
                 }
@@ -501,9 +496,7 @@ private:
                 options.erase("FILE");
 
             } else {
-
                 throw gpg_error(GPG_ERR_ASS_PARAMETER);
-
             }
 
             if (options.size()) {
@@ -513,7 +506,7 @@ private:
             (conn.*which).push_back(io);
 
             if (binOpt && !in) {
-                auto out = reinterpret_cast <Output *>(io.get());
+                auto out = reinterpret_cast<Output *>(io.get());
                 out->setBinaryOpt(true);
                 qCDebug(KLEOPATRA_LOG) << "Configured output for binary data";
             }
@@ -530,7 +523,6 @@ private:
         } catch (...) {
             return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_UNEXPECTED), "unknown exception caught");
         }
-
     }
 
     static gpg_error_t input_handler(assuan_context_t ctx, char *line)
@@ -618,7 +610,7 @@ private:
         return informative;
     }
 
-    template <typename T_memptr, typename T_memptr2>
+    template<typename T_memptr, typename T_memptr2>
     static gpg_error_t recipient_sender_handler(T_memptr mp, T_memptr2 info, assuan_context_t ctx, char *line, bool sender = false)
     {
         Q_ASSERT(assuan_get_pointer(ctx));
@@ -627,19 +619,20 @@ private:
         if (!line || !*line) {
             return assuan_process_done(conn.ctx.get(), gpg_error(GPG_ERR_INV_ARG));
         }
-        const char *begin     = line;
+        const char *begin = line;
         const char *const end = begin + qstrlen(line);
         GpgME::Protocol proto = GpgME::UnknownProtocol;
         const bool informative = parse_informative(begin, proto);
         if (!(conn.*mp).empty() && informative != (conn.*info))
-            return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_CONFLICT),
+            return assuan_process_done_msg(conn.ctx.get(),
+                                           gpg_error(GPG_ERR_CONFLICT),
                                            i18n("Cannot mix --info with non-info SENDER or RECIPIENT").toUtf8().constData());
         KMime::Types::Mailbox mb;
         if (!KMime::HeaderParsing::parseMailbox(begin, end, mb))
-            return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_INV_ARG),
-                                           i18n("Argument is not a valid RFC-2822 mailbox").toUtf8().constData());
+            return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_INV_ARG), i18n("Argument is not a valid RFC-2822 mailbox").toUtf8().constData());
         if (begin != end)
-            return assuan_process_done_msg(conn.ctx.get(), gpg_error(GPG_ERR_INV_ARG),
+            return assuan_process_done_msg(conn.ctx.get(),
+                                           gpg_error(GPG_ERR_INV_ARG),
                                            i18n("Garbage after valid RFC-2822 mailbox detected").toUtf8().constData());
         (conn.*info) = informative;
         (conn.*mp).push_back(mb);
@@ -677,7 +670,7 @@ private:
         return sl.join(QLatin1Char('\n')).toUtf8();
     }
 
-    template <typename T_container>
+    template<typename T_container>
     static QByteArray dumpStringList(const T_container &c)
     {
         QStringList sl;
@@ -685,15 +678,13 @@ private:
         return dumpStringList(sl);
     }
 
-    template <typename T_container>
+    template<typename T_container>
     static QByteArray dumpMailboxes(const T_container &c)
     {
         QStringList sl;
-        std::transform(c.begin(), c.end(),
-                       std::back_inserter(sl),
-                       [](typename T_container::const_reference val) {
-                           return val.prettyAddress();
-                       });
+        std::transform(c.begin(), c.end(), std::back_inserter(sl), [](typename T_container::const_reference val) {
+            return val.prettyAddress();
+        });
         return dumpStringList(sl);
     }
 
@@ -750,25 +741,25 @@ private:
 
     assuan_fd_t fd;
     AssuanContext ctx;
-    bool closed                : 1;
+    bool closed : 1;
     bool cryptoCommandsEnabled : 1;
     bool commandWaitingForCryptoCommandsEnabled : 1;
     bool currentCommandIsNohup : 1;
-    bool informativeSenders;    // address taken, so no : 1
+    bool informativeSenders; // address taken, so no : 1
     bool informativeRecipients; // address taken, so no : 1
     GpgME::Protocol bias;
     QString sessionTitle;
     unsigned int sessionId;
-    std::vector< std::shared_ptr<QSocketNotifier> > notifiers;
-    std::vector< std::shared_ptr<AssuanCommandFactory> > factories; // sorted: _detail::ByName<std::less>
+    std::vector<std::shared_ptr<QSocketNotifier>> notifiers;
+    std::vector<std::shared_ptr<AssuanCommandFactory>> factories; // sorted: _detail::ByName<std::less>
     std::shared_ptr<AssuanCommand> currentCommand;
-    std::vector< std::shared_ptr<AssuanCommand> > nohupedCommands;
+    std::vector<std::shared_ptr<AssuanCommand>> nohupedCommands;
     std::map<std::string, QVariant> options;
     std::vector<KMime::Types::Mailbox> senders, recipients;
-    std::vector< std::shared_ptr<Input> > inputs, messages;
-    std::vector< std::shared_ptr<Output> > outputs;
+    std::vector<std::shared_ptr<Input>> inputs, messages;
+    std::vector<std::shared_ptr<Output>> outputs;
     std::vector<QString> files;
-    std::map< QByteArray, std::shared_ptr<AssuanCommand::Memento> > mementos;
+    std::map<QByteArray, std::shared_ptr<AssuanCommand::Memento>> mementos;
 };
 
 void AssuanServerConnection::Private::cleanup()
@@ -783,19 +774,19 @@ void AssuanServerConnection::Private::cleanup()
     fd = ASSUAN_INVALID_FD;
 }
 
-AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories_, AssuanServerConnection *qq)
-    : QObject(),
-      q(qq),
-      fd(fd_),
-      closed(false),
-      cryptoCommandsEnabled(false),
-      commandWaitingForCryptoCommandsEnabled(false),
-      currentCommandIsNohup(false),
-      informativeSenders(false),
-      informativeRecipients(false),
-      bias(GpgME::UnknownProtocol),
-      sessionId(0),
-      factories(factories_)
+AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector<std::shared_ptr<AssuanCommandFactory>> &factories_, AssuanServerConnection *qq)
+    : QObject()
+    , q(qq)
+    , fd(fd_)
+    , closed(false)
+    , cryptoCommandsEnabled(false)
+    , commandWaitingForCryptoCommandsEnabled(false)
+    , currentCommandIsNohup(false)
+    , informativeSenders(false)
+    , informativeRecipients(false)
+    , bias(GpgME::UnknownProtocol)
+    , sessionId(0)
+    , factories(factories_)
 {
 #ifdef __GLIBCXX__
     Q_ASSERT(__gnu_cxx::is_sorted(factories_.begin(), factories_.end(), _detail::ByName<std::less>()));
@@ -824,7 +815,7 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std
     // register FDs with the event loop:
     assuan_fd_t fds[MAX_ACTIVE_FDS];
     const int numFDs = assuan_get_active_fds(ctx.get(), FOR_READING, fds, MAX_ACTIVE_FDS);
-    Q_ASSERT(numFDs != -1);   // == 1
+    Q_ASSERT(numFDs != -1); // == 1
 
     if (!numFDs || fds[0] != fd) {
         const std::shared_ptr<QSocketNotifier> sn(new QSocketNotifier((intptr_t)fd, QSocketNotifier::Read), std::mem_fn(&QObject::deleteLater));
@@ -840,9 +831,9 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std
     }
 
     // register our INPUT/OUTPUT/MESSGAE/FILE handlers:
-    if (const gpg_error_t err = assuan_register_command(ctx.get(), "INPUT",  input_handler, ""))
+    if (const gpg_error_t err = assuan_register_command(ctx.get(), "INPUT", input_handler, ""))
         throw Exception(err, "register \"INPUT\" handler");
-    if (const gpg_error_t err = assuan_register_command(ctx.get(), "MESSAGE",  message_handler, ""))
+    if (const gpg_error_t err = assuan_register_command(ctx.get(), "MESSAGE", message_handler, ""))
         throw Exception(err, "register \"MESSAGE\" handler");
     if (const gpg_error_t err = assuan_register_command(ctx.get(), "OUTPUT", output_handler, ""))
         throw Exception(err, "register \"OUTPUT\" handler");
@@ -870,7 +861,7 @@ AssuanServerConnection::Private::Private(assuan_fd_t fd_, const std::vector< std
         throw Exception(err, "register \"CAPABILITIES\" handler");
 
     assuan_set_hello_line(ctx.get(), "GPG UI server (Kleopatra/" KLEOPATRA_VERSION_STRING ") ready to serve");
-    //assuan_set_hello_line( ctx.get(), GPG UI server (qApp->applicationName() + " v" + kapp->applicationVersion() + "ready to serve" )
+    // assuan_set_hello_line( ctx.get(), GPG UI server (qApp->applicationName() + " v" + kapp->applicationVersion() + "ready to serve" )
 
     // some notifiers we're interested in:
     if (const gpg_error_t err = assuan_register_reset_notify(ctx.get(), reset_handler)) {
@@ -893,13 +884,15 @@ AssuanServerConnection::Private::~Private()
     cleanup();
 }
 
-AssuanServerConnection::AssuanServerConnection(assuan_fd_t fd, const std::vector< std::shared_ptr<AssuanCommandFactory> > &factories, QObject *p)
-    : QObject(p), d(new Private(fd, factories, this))
+AssuanServerConnection::AssuanServerConnection(assuan_fd_t fd, const std::vector<std::shared_ptr<AssuanCommandFactory>> &factories, QObject *p)
+    : QObject(p)
+    , d(new Private(fd, factories, this))
 {
-
 }
 
-AssuanServerConnection::~AssuanServerConnection() {}
+AssuanServerConnection::~AssuanServerConnection()
+{
+}
 
 void AssuanServerConnection::enableCryptoCommands(bool on)
 {
@@ -925,12 +918,10 @@ class InquiryHandler : public QObject
 {
     Q_OBJECT
 public:
-
     explicit InquiryHandler(const char *keyword_, QObject *p = nullptr)
-        : QObject(p),
-          keyword(keyword_)
+        : QObject(p)
+        , keyword(keyword_)
     {
-
     }
 
     static gpg_error_t handler(void *cb_data, gpg_error_t rc, unsigned char *buffer, size_t buflen)
@@ -956,18 +947,17 @@ class AssuanCommand::Private
 {
 public:
     Private()
-        : informativeRecipients(false),
-          informativeSenders(false),
-          bias(GpgME::UnknownProtocol),
-          done(false),
-          nohup(false)
+        : informativeRecipients(false)
+        , informativeSenders(false)
+        , bias(GpgME::UnknownProtocol)
+        , done(false)
+        , nohup(false)
     {
-
     }
 
     std::map<std::string, QVariant> options;
-    std::vector< std::shared_ptr<Input> > inputs, messages;
-    std::vector< std::shared_ptr<Output> > outputs;
+    std::vector<std::shared_ptr<Input>> inputs, messages;
+    std::vector<std::shared_ptr<Output>> outputs;
     std::vector<QString> files;
     std::vector<KMime::Types::Mailbox> recipients, senders;
     bool informativeRecipients, informativeSenders;
@@ -983,12 +973,10 @@ public:
 AssuanCommand::AssuanCommand()
     : d(new Private)
 {
-
 }
 
 AssuanCommand::~AssuanCommand()
 {
-
 }
 
 int AssuanCommand::start()
@@ -1056,7 +1044,7 @@ const std::map<std::string, QVariant> &AssuanCommand::options() const
 
 namespace
 {
-template <typename U, typename V>
+template<typename U, typename V>
 std::vector<U> keys(const std::map<U, V> &map)
 {
     std::vector<U> result;
@@ -1068,7 +1056,7 @@ std::vector<U> keys(const std::map<U, V> &map)
 }
 }
 
-const std::map< QByteArray, std::shared_ptr<AssuanCommand::Memento> > &AssuanCommand::mementos() const
+const std::map<QByteArray, std::shared_ptr<AssuanCommand::Memento>> &AssuanCommand::mementos() const
 {
     // oh, hack :(
     Q_ASSERT(assuan_get_pointer(d->ctx.get()));
@@ -1135,17 +1123,17 @@ void AssuanCommand::removeMemento(const QByteArray &tag)
     }
 }
 
-const std::vector< std::shared_ptr<Input> > &AssuanCommand::inputs() const
+const std::vector<std::shared_ptr<Input>> &AssuanCommand::inputs() const
 {
     return d->inputs;
 }
 
-const std::vector< std::shared_ptr<Input> > &AssuanCommand::messages() const
+const std::vector<std::shared_ptr<Input>> &AssuanCommand::messages() const
 {
     return d->messages;
 }
 
-const std::vector< std::shared_ptr<Output> > &AssuanCommand::outputs() const
+const std::vector<std::shared_ptr<Output>> &AssuanCommand::outputs() const
 {
     return d->outputs;
 }
@@ -1178,7 +1166,7 @@ void AssuanCommand::sendStatusEncoded(const char *keyword, const std::string &te
     }
 }
 
-void  AssuanCommand::sendData(const QByteArray &data, bool moreToCome)
+void AssuanCommand::sendData(const QByteArray &data, bool moreToCome)
 {
     if (d->nohup) {
         return;
@@ -1187,7 +1175,7 @@ void  AssuanCommand::sendData(const QByteArray &data, bool moreToCome)
         throw Exception(err, i18n("Cannot send data"));
     }
     if (!moreToCome)
-        if (const gpg_error_t err = assuan_send_data(d->ctx.get(), nullptr, 0)) {   // flush
+        if (const gpg_error_t err = assuan_send_data(d->ctx.get(), nullptr, 0)) { // flush
             throw Exception(err, i18n("Cannot flush data"));
         }
 }
@@ -1203,9 +1191,8 @@ int AssuanCommand::inquire(const char *keyword, QObject *receiver, const char *s
     }
 
     std::unique_ptr<InquiryHandler> ih(new InquiryHandler(keyword, receiver));
-    receiver->connect(ih.get(), SIGNAL(signal(int,QByteArray,QByteArray)), slot);
-    if (const gpg_error_t err = assuan_inquire_ext(d->ctx.get(), keyword,
-                                maxSize, InquiryHandler::handler, ih.get())) {
+    receiver->connect(ih.get(), SIGNAL(signal(int, QByteArray, QByteArray)), slot);
+    if (const gpg_error_t err = assuan_inquire_ext(d->ctx.get(), keyword, maxSize, InquiryHandler::handler, ih.get())) {
         return err;
     }
     ih.release();
@@ -1256,8 +1243,7 @@ void AssuanCommand::done(const GpgME::Error &err)
 
     const gpg_error_t rc = assuan_process_done(d->ctx.get(), err.encodedError());
     if (gpg_err_code(rc) != GPG_ERR_NO_ERROR)
-        qFatal("AssuanCommand::done: assuan_process_done returned error %d (%s)",
-               static_cast<int>(rc), gpg_strerror(rc));
+        qFatal("AssuanCommand::done: assuan_process_done returned error %d (%s)", static_cast<int>(rc), gpg_strerror(rc));
 
     d->utf8ErrorKeepAlive.clear();
 
@@ -1315,9 +1301,7 @@ gpg_error_t AssuanCommandFactory::_handle(assuan_context_t ctx, char *line, cons
     AssuanServerConnection::Private &conn = *static_cast<AssuanServerConnection::Private *>(assuan_get_pointer(ctx));
 
     try {
-
-        const auto it
-            = std::lower_bound(conn.factories.begin(), conn.factories.end(), commandName, _detail::ByName<std::less>());
+        const auto it = std::lower_bound(conn.factories.begin(), conn.factories.end(), commandName, _detail::ByName<std::less>());
         kleo_assert(it != conn.factories.end());
         kleo_assert(*it);
         kleo_assert(qstricmp((*it)->name(), commandName) == 0);
@@ -1325,19 +1309,25 @@ gpg_error_t AssuanCommandFactory::_handle(assuan_context_t ctx, char *line, cons
         const std::shared_ptr<AssuanCommand> cmd = (*it)->create();
         kleo_assert(cmd);
 
-        cmd->d->ctx     = conn.ctx;
+        cmd->d->ctx = conn.ctx;
         cmd->d->options = conn.options;
-        cmd->d->inputs.swap(conn.inputs);     kleo_assert(conn.inputs.empty());
-        cmd->d->messages.swap(conn.messages); kleo_assert(conn.messages.empty());
-        cmd->d->outputs.swap(conn.outputs);   kleo_assert(conn.outputs.empty());
-        cmd->d->files.swap(conn.files);       kleo_assert(conn.files.empty());
-        cmd->d->senders.swap(conn.senders);   kleo_assert(conn.senders.empty());
-        cmd->d->recipients.swap(conn.recipients); kleo_assert(conn.recipients.empty());
+        cmd->d->inputs.swap(conn.inputs);
+        kleo_assert(conn.inputs.empty());
+        cmd->d->messages.swap(conn.messages);
+        kleo_assert(conn.messages.empty());
+        cmd->d->outputs.swap(conn.outputs);
+        kleo_assert(conn.outputs.empty());
+        cmd->d->files.swap(conn.files);
+        kleo_assert(conn.files.empty());
+        cmd->d->senders.swap(conn.senders);
+        kleo_assert(conn.senders.empty());
+        cmd->d->recipients.swap(conn.recipients);
+        kleo_assert(conn.recipients.empty());
         cmd->d->informativeRecipients = conn.informativeRecipients;
-        cmd->d->informativeSenders    = conn.informativeSenders;
-        cmd->d->bias                  = conn.bias;
-        cmd->d->sessionTitle          = conn.sessionTitle;
-        cmd->d->sessionId             = conn.sessionId;
+        cmd->d->informativeSenders = conn.informativeSenders;
+        cmd->d->bias = conn.bias;
+        cmd->d->sessionTitle = conn.sessionTitle;
+        cmd->d->sessionId = conn.sessionId;
 
         const std::map<std::string, std::string> cmdline_options = parse_commandline(line);
         for (auto it = cmdline_options.begin(), end = cmdline_options.end(); it != end; ++it) {
@@ -1371,7 +1361,6 @@ gpg_error_t AssuanCommandFactory::_handle(assuan_context_t ctx, char *line, cons
 
 int AssuanServerConnection::Private::startCommandBottomHalf()
 {
-
     commandWaitingForCryptoCommandsEnabled = currentCommand && !cryptoCommandsEnabled;
 
     if (!cryptoCommandsEnabled) {
@@ -1389,7 +1378,6 @@ int AssuanServerConnection::Private::startCommandBottomHalf()
     currentCommandIsNohup = false;
 
     try {
-
         if (const int err = cmd->start()) {
             if (cmd->isDone()) {
                 return err;
@@ -1418,7 +1406,6 @@ int AssuanServerConnection::Private::startCommandBottomHalf()
     } catch (...) {
         return assuan_process_done_msg(ctx.get(), gpg_error(GPG_ERR_UNEXPECTED), i18n("Caught unknown exception"));
     }
-
 }
 
 //
@@ -1502,3 +1489,5 @@ WId AssuanCommand::parentWId() const
 }
 
 #include "assuanserverconnection.moc"
+
+#include "moc_assuanserverconnection.cpp"
