@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef __KLEOPATRA_UISERVER_CREATECHECKSUMSCOMMAND_H__
-#define __KLEOPATRA_UISERVER_CREATECHECKSUMSCOMMAND_H__
+#pragma once
 
 #include "assuancommand.h"
 #include <QObject>
@@ -46,5 +45,3 @@ private:
 };
 
 }
-
-#endif /* __KLEOPATRA_UISERVER_CREATECHECKSUMSCOMMAND_H__ */
