@@ -11,13 +11,13 @@
 
 #include "dragqueen.h"
 
+#include <QApplication>
 #include <QDrag>
 #include <QMouseEvent>
 #include <QStringList>
-#include <QVariant>
-#include <QApplication>
-#include <QUrl>
 #include <QStyle>
+#include <QUrl>
+#include <QVariant>
 
 #include <algorithm>
 
@@ -30,9 +30,9 @@ class MimeDataProxy : public QMimeData
     Q_OBJECT
 public:
     explicit MimeDataProxy(QMimeData *source)
-        : QMimeData(), m_source(source)
+        : QMimeData()
+        , m_source(source)
     {
-
     }
 
     QStringList formats() const override
@@ -50,27 +50,15 @@ public:
     }
 
 protected:
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QVariant retrieveData(const QString &format, QVariant::Type type) const override
-#else
     QVariant retrieveData(const QString &format, QMetaType type) const override
-#endif
     {
         if (!m_source) {
             return QVariant();
         }
         // Doesn't work, is protected:
         // return m_source->retrieveData( format, type );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        switch (type) {
-#else
         switch (type.id()) {
-#endif
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        case QVariant::String:
-#else
         case QMetaType::QString:
-#endif
             if (format == QLatin1String("text/plain")) {
                 return m_source->text();
             }
@@ -78,39 +66,25 @@ protected:
                 return m_source->html();
             }
             break;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        case QVariant::Color:
-#else
         case QMetaType::QColor:
-#endif
             if (format == QLatin1String("application/x-color")) {
                 return m_source->colorData();
             }
             break;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        case QVariant::Image:
-#else
         case QMetaType::QImage:
-#endif
             if (format == QLatin1String("application/x-qt-image")) {
                 return m_source->imageData();
             }
             break;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        case QVariant::List:
-        case QVariant::Url:
-#else
         case QMetaType::QVariantList:
         case QMetaType::QUrl:
-#endif
             if (format == QLatin1String("text/uri-list")) {
                 const QList<QUrl> urls = m_source->urls();
                 if (urls.size() == 1) {
                     return urls.front();
                 }
                 QList<QVariant> result;
-                std::copy(urls.begin(), urls.end(),
-                          std::back_inserter(result));
+                std::copy(urls.begin(), urls.end(), std::back_inserter(result));
                 return result;
             }
             break;
@@ -122,25 +96,24 @@ protected:
         v.convert(type);
         return v;
     }
+
 private:
     QPointer<QMimeData> m_source;
 };
 }
 
 DragQueen::DragQueen(QWidget *p, Qt::WindowFlags f)
-    : QLabel(p, f),
-      m_data(),
-      m_dragStartPosition()
+    : QLabel(p, f)
+    , m_data()
+    , m_dragStartPosition()
 {
-
 }
 
 DragQueen::DragQueen(const QString &t, QWidget *p, Qt::WindowFlags f)
-    : QLabel(t, p, f),
-      m_data(),
-      m_dragStartPosition()
+    : QLabel(t, p, f)
+    , m_data()
+    , m_dragStartPosition()
 {
-
 }
 
 DragQueen::~DragQueen()
@@ -205,11 +178,11 @@ static QPoint calculate_hot_spot(const QPoint &mouse, const QSize &pix, const QL
 void DragQueen::mouseMoveEvent(QMouseEvent *e)
 {
 #ifndef QT_NO_DRAGANDDROP
-    if (m_data &&
-            (e->buttons() & Qt::LeftButton) &&
-            (m_dragStartPosition - e->pos()).manhattanLength() > QApplication::startDragDistance()) {
+    if (m_data //
+        && (e->buttons() & Qt::LeftButton) //
+        && (m_dragStartPosition - e->pos()).manhattanLength() > QApplication::startDragDistance()) {
         auto drag = new QDrag(this);
-        const QPixmap pix = pixmap(Qt::ReturnByValue);
+        const QPixmap pix = pixmap();
         if (!pix.isNull()) {
             drag->setPixmap(pix);
             drag->setHotSpot(calculate_hot_spot(e->pos(), pix.size(), this));
@@ -225,3 +198,5 @@ void DragQueen::mouseMoveEvent(QMouseEvent *e)
 }
 
 #include "dragqueen.moc"
+
+#include "moc_dragqueen.cpp"
