@@ -12,10 +12,9 @@
 
 #include "keyparameters.h"
 
-#include "keyusage.h"
+#include <Libkleo/KeyUsage>
 
 #include <QDate>
-#include <QMap>
 #include <QUrl>
 
 #include "kleopatra_debug.h"
@@ -25,20 +24,20 @@ using namespace GpgME;
 
 namespace
 {
-    QString encodeDomainName(const QString &domain)
-    {
-        const QByteArray encodedDomain = QUrl::toAce(domain);
-        return encodedDomain.isEmpty() ? domain : QString::fromLatin1(encodedDomain);
-    }
+QString encodeDomainName(const QString &domain)
+{
+    const QByteArray encodedDomain = QUrl::toAce(domain);
+    return encodedDomain.isEmpty() ? domain : QString::fromLatin1(encodedDomain);
+}
 
-    QString encodeEmail(const QString &email)
-    {
-        const int at = email.lastIndexOf(QLatin1Char('@'));
-        if (at < 0) {
-            return email;
-        }
-        return email.left(at + 1) + encodeDomainName(email.mid(at + 1));
+QString encodeEmail(const QString &email)
+{
+    const int at = email.lastIndexOf(QLatin1Char('@'));
+    if (at < 0) {
+        return email;
     }
+    return email.left(at + 1) + encodeDomainName(email.mid(at + 1));
+}
 }
 
 class KeyParameters::Private
@@ -59,6 +58,7 @@ class KeyParameters::Private
     KeyUsage subkeyUsage;
 
     QString name;
+    QString comment;
     QString dn;
     std::vector<QString> emailAdresses;
     std::vector<QString> domainNames;
@@ -215,6 +215,16 @@ QString KeyParameters::name() const
     return d->name;
 }
 
+void KeyParameters::setComment(const QString &comment)
+{
+    d->comment = comment;
+}
+
+QString KeyParameters::comment() const
+{
+    return d->comment;
+}
+
 void KeyParameters::setDN(const QString &dn)
 {
     d->dn = dn;
@@ -230,7 +240,7 @@ void KeyParameters::setEmail(const QString &email)
     d->emailAdresses = {email};
 }
 
-void KeyParameters::addEmail(const QString& email)
+void KeyParameters::addEmail(const QString &email)
 {
     d->emailAdresses.push_back(email);
 }
@@ -240,7 +250,7 @@ std::vector<QString> KeyParameters::emails() const
     return d->emailAdresses;
 }
 
-void KeyParameters::addDomainName(const QString& domain)
+void KeyParameters::addDomainName(const QString &domain)
 {
     d->domainNames.push_back(domain);
 }
@@ -250,7 +260,7 @@ std::vector<QString> KeyParameters::domainNames() const
     return d->domainNames;
 }
 
-void KeyParameters::addURI(const QString& uri)
+void KeyParameters::addURI(const QString &uri)
 {
     d->uris.push_back(uri);
 }
@@ -348,6 +358,9 @@ QString KeyParameters::toString() const
     if (!d->name.isEmpty()) {
         keyParameters.push_back(serialize("Name-Real", d->name));
     }
+    if (!d->comment.isEmpty()) {
+        keyParameters.push_back(serialize("Name-Comment", d->comment));
+    }
     if (!d->dn.isEmpty()) {
         keyParameters.push_back(serialize("Name-DN", d->dn));
     }
