@@ -10,7 +10,8 @@
 
 #pragma once
 
-#include <Qt>
+#include <QDebug>
+
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 // define some bitwise operators to avoid warning that bitwise operation between
 // different enumeration types is deprecated
@@ -19,3 +20,10 @@ inline int operator|(Qt::Modifier modifier, Qt::Key key)
     return static_cast<int>(modifier) | static_cast<int>(key);
 }
 #endif
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 5, 0)
+inline QDebug operator<<(QDebug s, const std::string &string)
+{
+    return s << QString::fromStdString(string);
+}
+#endif
