@@ -14,10 +14,10 @@
 
 #include "commands/changepincommand.h"
 
-#include <QVBoxLayout>
 #include <QHBoxLayout>
-#include <QPushButton>
 #include <QLabel>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -29,9 +29,10 @@ using namespace Kleo::SmartCard;
 NullPinWidget::NullPinWidget(QWidget *parent)
     : QWidget(parent)
 {
-    const auto nullTitle = i18nc("NullPIN is a word that is used all over in the netkey "
-                                 "documentation and should be understandable by Netkey cardholders",
-                                 "The NullPIN is still active on this card.");
+    const auto nullTitle = i18nc(
+        "NullPIN is a word that is used all over in the netkey "
+        "documentation and should be understandable by Netkey cardholders",
+        "The NullPIN is still active on this card.");
     const auto nullDescription = i18n("You need to set a PIN before you can use the certificates.");
     const auto descriptionLbl = new QLabel(QStringLiteral("<b>%1</b><br/>%2").arg(nullTitle, nullDescription));
 
@@ -41,12 +42,12 @@ NullPinWidget::NullPinWidget(QWidget *parent)
     mNKSBtn = new QPushButton(i18nc("NKS is an identifier for a type of keys on a NetKey card", "Set NKS PIN"));
     mSigGBtn = new QPushButton(i18nc("SigG is an identifier for a type of keys on a NetKey card", "Set SigG PIN"));
 
-    connect(mNKSBtn, &QPushButton::clicked, this, [this] () {
-            doChangePin(NetKeyCard::nksPinKeyRef());
-        });
-    connect(mSigGBtn, &QPushButton::clicked, this, [this] () {
-            doChangePin(NetKeyCard::sigGPinKeyRef());
-        });
+    connect(mNKSBtn, &QPushButton::clicked, this, [this]() {
+        doChangePin(NetKeyCard::nksPinKeyRef());
+    });
+    connect(mSigGBtn, &QPushButton::clicked, this, [this]() {
+        doChangePin(NetKeyCard::sigGPinKeyRef());
+    });
 
     auto hLayBtn = new QHBoxLayout;
     hLayBtn->addStretch(1);
@@ -66,15 +67,15 @@ void NullPinWidget::doChangePin(const std::string &keyRef)
 {
     parentWidget()->setEnabled(false);
     auto ret = KMessageBox::warningContinueCancel(this,
-            i18n("Setting a PIN is required but <b>can't be reverted</b>.") +
-            QStringLiteral("<p>%1</p><p>%2</p>").arg(
-                i18n("If you proceed you will be asked to enter a new PIN "
-                     "and later to repeat that PIN.")).arg(
-                i18n("It will <b>not be possible</b> to recover the "
-                     "card if the PIN has been entered wrongly more than 2 times.")),
-            i18n("Set initial PIN"),
-            KStandardGuiItem::cont(),
-            KStandardGuiItem::cancel());
+                                                  i18n("Setting a PIN is required but <b>can't be reverted</b>.")
+                                                      + QStringLiteral("<p>%1</p><p>%2</p>")
+                                                            .arg(i18n("If you proceed you will be asked to enter a new PIN "
+                                                                      "and later to repeat that PIN."))
+                                                            .arg(i18n("It will <b>not be possible</b> to recover the "
+                                                                      "card if the PIN has been entered wrongly more than 2 times.")),
+                                                  i18nc("@title:window", "Set initial PIN"),
+                                                  KStandardGuiItem::cont(),
+                                                  KStandardGuiItem::cancel());
 
     if (ret != KMessageBox::Continue) {
         parentWidget()->setEnabled(true);
@@ -82,10 +83,9 @@ void NullPinWidget::doChangePin(const std::string &keyRef)
     }
 
     auto cmd = new ChangePinCommand(mSerialNumber, NetKeyCard::AppName, this);
-    connect(cmd, &ChangePinCommand::finished,
-            this, [this]() {
-                this->parentWidget()->setEnabled(true);
-            });
+    connect(cmd, &ChangePinCommand::finished, this, [this]() {
+        this->parentWidget()->setEnabled(true);
+    });
     cmd->setKeyRef(keyRef);
     cmd->setMode(ChangePinCommand::NullPinMode);
     cmd->start();
@@ -100,3 +100,5 @@ void NullPinWidget::setNKSVisible(bool val)
 {
     mNKSBtn->setVisible(val);
 }
+
+#include "moc_nullpinwidget.cpp"
